/*
** GtkCombo.c
** 
** Made by (Maxime VERNIER)
** Login   <vernie_m@epita.fr>
** 
** Started on  Tue Jun  1 15:24:01 1999 Maxime VERNIER
** Last update Sat Apr  1 02:36:56 2000 Sebastien Thebert
*/
#include "main.h"
#include "put_widget.h"
#include "properties.h"
#include "restore.h"
#include "widget_events.h"

void		list_changed(GtkWidget *listbox)
{
  GtkWidget	*widget;
  
  widget = get_current_widget();
  if (!GTK_CLIST(listbox)->row_list)
    gtk_list_clear_items(GTK_LIST(GTK_COMBO(widget)->list),0,-1);
  else
    {
      gint	i;
      GList	*list = NULL;
      for(i = 1;i <= GTK_CLIST(listbox)->rows; i++)
	{
	  gchar		*text;
	  gtk_clist_get_text(GTK_CLIST(listbox), i - 1 ,0, &text);
	  list = g_list_append(list, text);
	}
      gtk_combo_set_popdown_strings(GTK_COMBO(widget), list);
    }
}

void		add_list_item_cb(GtkWidget *sender, GtkWidget *listbox)
{
  GtkWidget	*entry;
  gchar		*text;
  
  if (GTK_IS_BUTTON(sender))
    entry = gtk_object_get_data(GTK_OBJECT(sender), "entry");
  else
    entry = sender;
  text = gtk_entry_get_text(GTK_ENTRY(entry));
  gtk_clist_append(GTK_CLIST(listbox), &text);
  gtk_entry_set_text(GTK_ENTRY(entry), "");
  list_changed(listbox);
}

void	del_list_item_cb(GtkWidget *sender, GtkWidget *list)
{
  while (GTK_CLIST(list)->selection)
    gtk_clist_remove(GTK_CLIST(list), 
		     GPOINTER_TO_INT(GTK_CLIST(list)->selection->data));
  list_changed(list);
}

void	clr_list_items_cb(GtkWidget *sender, GtkWidget *list)
{
  gtk_clist_clear(GTK_CLIST(list));
  list_changed(list);
}

void		GtkCombo_properties(GtkWidget *widget)
{
  GtkWidget	*notebook;
  GtkWidget	*label;
  GtkWidget	*frame;
  GtkWidget	*table;
  GtkWidget	*entry;
  GtkWidget	*button;
  GtkWidget	*listbox;
  GList		*list, *node;
  
  notebook = gtk_object_get_data(GTK_OBJECT(epingle->win_properties),
				 "notebook");
  label = gtk_label_new("Items");
  frame = gtk_frame_new("List of items");
  table = gtk_table_new(2, 3, FALSE);
  listbox = gtk_clist_new(1);
  gtk_clist_set_selection_mode(GTK_CLIST(listbox), GTK_SELECTION_MULTIPLE);
  list = GTK_LIST(GTK_COMBO(widget)->list)->children;
  for(node = list; node; node = node->next)
    {
      GList		*children;
      GtkWidget		*label;
      gchar		*text;
      
      children = gtk_container_children(GTK_CONTAINER(node->data));
      label = g_list_first(children)->data;
      gtk_label_get(GTK_LABEL(label), &text);
      gtk_clist_append(GTK_CLIST(listbox),&text);
    }
  gtk_table_attach_defaults(GTK_TABLE(table), listbox, 0, 1, 1, 3);
  gtk_widget_show(listbox);
  entry = gtk_entry_new();
  gtk_signal_connect(GTK_OBJECT(entry),"activate",
		     GTK_SIGNAL_FUNC(add_list_item_cb), listbox);
  gtk_table_attach_defaults(GTK_TABLE(table), entry, 0, 1, 0, 1);
  gtk_widget_show(entry);
  button = gtk_button_new_with_label("Add");
  gtk_object_set_data(GTK_OBJECT(button), "entry", entry);
  gtk_signal_connect(GTK_OBJECT(button),"clicked",
		     GTK_SIGNAL_FUNC(add_list_item_cb), listbox);
  gtk_table_attach_defaults(GTK_TABLE(table),button,1,2,0,1);
  gtk_widget_show(button);
  button = gtk_button_new_with_label("Del");
  gtk_signal_connect(GTK_OBJECT(button),"clicked",
		     GTK_SIGNAL_FUNC(del_list_item_cb),listbox);
  gtk_table_attach_defaults(GTK_TABLE(table),button,1,2,1,2);
  gtk_widget_show(button);
  button = gtk_button_new_with_label("Clr");
  gtk_signal_connect(GTK_OBJECT(button),"clicked",
		     GTK_SIGNAL_FUNC(clr_list_items_cb),listbox);
  gtk_table_attach_defaults(GTK_TABLE(table),button,1,2,2,3);
  gtk_widget_show(button);
  gtk_container_add(GTK_CONTAINER(frame),table);
  gtk_widget_show(table);
  gtk_widget_show(frame);
  gtk_notebook_insert_page(GTK_NOTEBOOK(notebook),frame,label,1);
}

void		GtkCombo_save(FILE *fp, gint tab, GtkWidget *widget)
{
  gint		i;
  gint		nb_items;
  GtkWidget	*list;
  GList		*children;
  
  for(i = 1; i <= tab; i++)
    fprintf(fp, "\t");
  list = GTK_COMBO(widget)->list;
  children = gtk_container_children(GTK_CONTAINER(list));
  nb_items = g_list_length(children);
  fprintf(fp, "<NB_ITEMS>\t%d\n", nb_items);
  for(i = 0; i < nb_items; i++) 
    {
      gint	j;
      GtkWidget	*ListItem;
      GtkWidget	*label_widget;
      gchar	*label;
      
      for(j = 1; j <= tab; j++)
	fprintf(fp, "\t");
      ListItem = g_list_nth(children,i)->data;
      label_widget = g_list_first(gtk_container_children
				  (GTK_CONTAINER(ListItem)))->data;
      gtk_label_get(GTK_LABEL(label_widget),&label);
      fprintf(fp, "<ITEM>\t\t%s\n", label);
    }
}

GtkWidget	*GtkCombo_restore(FILE *fp, gint nb_tab)
{
  GtkWidget	*eventbox, *combo;
  GList		*list = NULL;
  gint		i, nb_items;
  
  eventbox = gtk_event_box_new();
  set_widget_events(eventbox);
  gtk_widget_show(eventbox);
  combo = gtk_combo_new();
  for(i = 1; i <= nb_tab + 1; i++)
    fscanf(fp, "\t");
  fscanf(fp, "%*s\t%d\n", &nb_items);
  for(i = 0;i < nb_items; i++)
    {
      gint	j;
      gchar	*label;
      for(j = 1; j <= nb_tab + 1; j++)
	fscanf(fp, "\t");
      label = get_text_property(fp,nb_tab);
      list = g_list_append(list, label);
    }
  if (list)
    gtk_combo_set_popdown_strings(GTK_COMBO(combo), list);
  gtk_container_add(GTK_CONTAINER(eventbox), combo);
  gtk_widget_show(combo);
  return (combo);
}

