/*
** compilation_options.c
** 
** Made by (Sebastien Thebert)
** Login   <theber_s@epita.fr>
** 
** Started on  Mon Apr  3 01:33:34 2000 Sebastien Thebert
** Last update Tue Apr  4 17:44:32 2000 Sebastien Thebert
*/
#include "main.h"

int	opt_wall, opt_debug, opt_optimization;
int	old_opt_wall, old_opt_debug, old_opt_optimization;

/*
** init gcc options
*/
char	*init_gcc_options(short opt_c)
{
  char	*command_line;
  
  command_line = xmalloc(sizeof (char) * LENGTH);
  strcpy(command_line, "gcc ");
  if (opt_c == 1)
    strcat(command_line, "-c ");
  if (opt_wall == 1)
    strcat(command_line, "-Wall ");
  if (opt_debug == 1)
    strcat(command_line, "-g ");
  if (opt_optimization != 0)
    {
      if (opt_optimization == 1)
	strcat(command_line, "-O1 ");
      else
	strcat(command_line, "-O2 ");
    }
  return(command_line);
}

/***********************************************************/
void	opt_compil_debug(GtkWidget *sender)
{
  if (GTK_TOGGLE_BUTTON(sender)->active) 
    opt_debug = 1;
  else
    opt_debug = 0;
}

/***********************************************************/
void	opt_compil_Wall(GtkWidget *sender)
{
  if (GTK_TOGGLE_BUTTON(sender)->active) 
    opt_wall = 1;
  else
    opt_wall = 0;
}

/***********************************************************/
void	opt_compil_optimization(GtkWidget *sender, gpointer level)
{
  opt_optimization = (int)level;
}

/***********************************************************/
void	load_default_compilation_options()
{
  FILE		*file;
  char		*option;
  int		value;
  
  option = xmalloc(sizeof (char) * LENGTH);
  if ((file = fopen("./EPIngle_opt_compil.cfg","r")) != NULL)
    {
      fscanf(file, "%s\n", option);
      fscanf(file, "%s\t%d\n", option, &value);
      opt_wall = value;
      fscanf(file, "%s\t%d\n", option, &value);
      opt_debug = value;
      fscanf(file, "%s\t%d\n", option, &value);
      opt_optimization = value;
      fclose(file);
    }
  else
    g_error("EPingle ERROR: Can't find default compilation options !\n");
  free(option);
}

/*
** save_default_compilation_options
*/
void	save_default_compilation_options(GtkWidget *sender, GtkWidget *win)
{
  FILE	*file;
  
  if ((file = fopen("./EPIngle_opt_compil.cfg","w")) != NULL)
    {
      fprintf(file, "<COMPILATION_OPTIONS>\n");
      fprintf(file, "%s\t%d\n", "-Wall", opt_wall);
      fprintf(file, "%s\t%d\n", "-Debug", opt_debug); 
      fprintf(file, "%s\t%d\n", "Optimization", opt_optimization);
      fclose(file);
    }
  else
    g_error("EPingle ERROR: Can't save default compilation options !\n");  
  gtk_widget_destroy(win);
}

/***********************************************************/
void	bt_ok_compilation_options(GtkWidget *sender, GtkWidget *win)
{
  gtk_widget_destroy(win);
}

/***********************************************************/
void	restore_old_compilation_values(GtkWidget *sender, GtkWidget *win)
{
  opt_wall = old_opt_wall;
  opt_debug = old_opt_debug;
  opt_optimization = old_opt_optimization;
  gtk_widget_destroy(win);
}


/*
** compilation_options
*/
void	compilation_options(GtkWidget *sender)
{
  GtkWidget	*win;
  GtkWidget	*vbox, *hbox, *hbox_frame, *frame, *check_bt;
  GtkTooltips	*tooltips;
  GtkWidget	*bt, *r_bt;
  GSList	*group;
  
  old_opt_wall = opt_wall;
  old_opt_debug = opt_debug;
  old_opt_optimization = opt_optimization;
  
  win = gtk_window_new(GTK_WINDOW_TOPLEVEL);
  gtk_window_set_title(GTK_WINDOW(win), "Compilation Options");
  tooltips = gtk_tooltips_new();
  vbox = gtk_vbox_new(FALSE,0);
  hbox = gtk_hbox_new(FALSE,0);
  check_bt = gtk_check_button_new_with_label("-Debug");
  gtk_signal_connect(GTK_OBJECT(check_bt), "clicked",
		     GTK_SIGNAL_FUNC(opt_compil_debug),NULL);
  if (opt_debug == 1)
    gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(check_bt), TRUE);
  gtk_widget_show(check_bt);
  gtk_tooltips_set_tip(tooltips, check_bt,
		       "Activate -Debug Compilation Option", NULL);
  gtk_box_pack_start(GTK_BOX(vbox), check_bt, FALSE, FALSE, 5);
  
  check_bt = gtk_check_button_new_with_label("-Wall");
  gtk_signal_connect(GTK_OBJECT(check_bt), "clicked",
		     GTK_SIGNAL_FUNC(opt_compil_Wall),NULL);
  if (opt_wall == 1)
    gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(check_bt), TRUE);
  gtk_widget_show(check_bt);
  gtk_tooltips_set_tip(tooltips, check_bt,
		       "Activate All Warnings", NULL);
  gtk_box_pack_start(GTK_BOX(vbox), check_bt, FALSE, FALSE, 5);
  gtk_widget_show(vbox);
  gtk_box_pack_start(GTK_BOX(hbox), vbox, FALSE, FALSE, 5);
  
  vbox = gtk_vbox_new(FALSE,0);
  frame = gtk_frame_new("Optimization Options");
  gtk_widget_show(frame);
  hbox_frame = gtk_hbox_new(FALSE,0);
  gtk_container_add(GTK_CONTAINER(frame), hbox_frame); 
  
  r_bt = gtk_radio_button_new_with_label(NULL, "None");
  gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(r_bt), TRUE);
  gtk_box_pack_start(GTK_BOX(hbox_frame), r_bt, FALSE, FALSE, 5);
  gtk_signal_connect(GTK_OBJECT(r_bt), "clicked",
		     GTK_SIGNAL_FUNC(opt_compil_optimization), (gpointer)0);
  if (opt_optimization == 0)
    gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(r_bt), TRUE);
  gtk_widget_show(r_bt);
  gtk_tooltips_set_tip(tooltips, r_bt, "No Optimization", NULL);  
  group = gtk_radio_button_group(GTK_RADIO_BUTTON(r_bt));
  r_bt = gtk_radio_button_new_with_label(group, "Level 1");
  gtk_box_pack_start(GTK_BOX(hbox_frame), r_bt, FALSE, FALSE, 5);
  gtk_signal_connect(GTK_OBJECT(r_bt), "clicked",
		     GTK_SIGNAL_FUNC(opt_compil_optimization), (gpointer)1);
  if (opt_optimization == 1)
    gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(r_bt), TRUE);
  gtk_widget_show(r_bt);
  gtk_tooltips_set_tip(tooltips, r_bt,
		       "Activate Optimization Level 1", NULL); 
  group = gtk_radio_button_group(GTK_RADIO_BUTTON(r_bt));
  r_bt = gtk_radio_button_new_with_label(group, "Level 2");
  gtk_box_pack_start(GTK_BOX(hbox_frame), r_bt, FALSE, FALSE, 5);
  gtk_signal_connect(GTK_OBJECT(r_bt), "clicked",
		     GTK_SIGNAL_FUNC(opt_compil_optimization), (gpointer)2);
  if (opt_optimization == 2)
    gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(r_bt), TRUE);
  gtk_widget_show(r_bt);
  gtk_tooltips_set_tip(tooltips, r_bt,
		       "Activate Optimization Level 2", NULL); 
  gtk_widget_show(hbox_frame);
  gtk_box_pack_start(GTK_BOX(hbox), frame, FALSE, FALSE, 5);
  gtk_widget_show(hbox);
  gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 5);
  
  hbox = gtk_hbox_new(FALSE,0);
  bt = gtk_button_new_with_label("Ok");
  gtk_box_pack_start(GTK_BOX(hbox), bt, TRUE, TRUE, 5);
  gtk_signal_connect(GTK_OBJECT(bt), "clicked",
		     GTK_SIGNAL_FUNC(bt_ok_compilation_options), win);
  gtk_widget_show(bt);
  bt = gtk_button_new_with_label("Cancel");
  gtk_box_pack_start(GTK_BOX(hbox), bt, TRUE, TRUE, 5);
  gtk_signal_connect(GTK_OBJECT(bt), "clicked",
		     GTK_SIGNAL_FUNC(restore_old_compilation_values),
		     win);
  gtk_widget_show(bt);
  bt = gtk_button_new_with_label("Save Default");
  gtk_box_pack_start(GTK_BOX(hbox), bt, TRUE, TRUE, 5);
  gtk_signal_connect(GTK_OBJECT(bt), "clicked",
		     GTK_SIGNAL_FUNC(save_default_compilation_options),
		     win);
  gtk_widget_show(bt);
  gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 5);
  gtk_widget_show(hbox);
  gtk_widget_show(vbox);
  
  gtk_container_add(GTK_CONTAINER(win), vbox);
  gtk_widget_show(win);
}

