/*
** create_widget.c
** 
** Made by (sebastien thebert)
** Login   <theber_s@epita.fr>
** 
** Started on  Mon May 31 01:01:50 1999 sebastien thebert
** Last update Tue Apr  4 18:10:52 2000 Sebastien Thebert
*/
#include "main.h"

extern GtkWidget	*clist_popup;

/*
** Set widget's coordinates
*/
void	set_widget_coordinates(GtkWidget *widget, gint x, gint y,
			       gint width, gint height)
{
  widget->allocation.x = x;
  widget->allocation.y = y;
  widget->allocation.width = width;
  widget->allocation.height = height;
}

/*
** Get widget's parent window
*/
GtkWidget	*get_win_parent(GtkWidget *widget)
{
  GtkWidget	*win_parent;
  
  win_parent = widget;
  while (!GTK_IS_WINDOW(win_parent))
    win_parent = win_parent->parent;
  return (win_parent);
}

/*
** create_option_menu
*/
GtkWidget	*create_option_menu(GtkWidget *fixed, gint x, gint y,
				    gint width, gint height, GList *list)
{
  GtkWidget	*option_menu;
  GtkWidget	*menu;
  GtkWidget	*m_item;
  gint		i;
  gchar		*text;
  
  menu = NULL;
  if (list)
    {
      menu = gtk_menu_new();
      for(i = 0; i < g_list_length(list); i++)
	{
	  text = g_list_nth(list, i)->data;
	  m_item = gtk_menu_item_new_with_label(text);
	  gtk_widget_show(m_item);
	  gtk_menu_append(GTK_MENU(menu), m_item);
	}
    }
  option_menu = gtk_option_menu_new();
  /*  set_widget_events(option_menu);*/
  dragndrop_set_src(option_menu);
  gtk_widget_set_usize(option_menu, width, height);
  gtk_widget_show(option_menu);
  if (list)
    gtk_option_menu_set_menu(GTK_OPTION_MENU(option_menu), menu);
  gtk_fixed_put(GTK_FIXED(fixed), option_menu, x, y);
  set_widget_coordinates(option_menu, x, y, width, height);
  return (option_menu);
}

/*
** create_progress_bar
*/
GtkWidget	*create_progress_bar(GtkWidget *fixed, gint x, gint y,
				     gint width, gint height,
				     GtkProgressBarOrientation orientation,
				     GtkProgressBarStyle style,
				     gint show_text, gfloat percentage)
{
  GtkWidget	*progress_bar;
  
  progress_bar = gtk_progress_bar_new();
  set_widget_events(progress_bar);
  dragndrop_set_src(progress_bar);
  gtk_widget_set_usize(progress_bar, width, height);
  gtk_progress_bar_set_orientation(GTK_PROGRESS_BAR(progress_bar),
				   orientation); 
  gtk_progress_bar_update(GTK_PROGRESS_BAR(progress_bar), percentage);
  gtk_progress_bar_set_bar_style(GTK_PROGRESS_BAR(progress_bar), style);
  gtk_progress_set_show_text(GTK_PROGRESS(progress_bar), show_text);
  gtk_widget_show(progress_bar);
  gtk_fixed_put(GTK_FIXED(fixed), progress_bar, x, y);
  set_widget_coordinates(progress_bar, x, y, width, height);
  return (progress_bar); 
}

/*
** create_statusbar
*/
GtkWidget	*create_statusbar(GtkWidget *fixed, gint x, gint y,
				  gint width, gint height)
{
  GtkWidget	*statusbar;
  
  statusbar = gtk_statusbar_new(); 
  gtk_widget_show(statusbar);
  return (statusbar);
}

/*
** create_toolbar
*/
GtkWidget	*create_toolbar(GtkWidget *fixed, gint x, gint y,
				gint width, gint height,
				gint orientation, gint type)
{
  GtkWidget	*toolbar;
  
  toolbar = gtk_toolbar_new(orientation, type);
  gtk_widget_set_usize(toolbar, width, height);
  gtk_container_set_border_width(GTK_CONTAINER(toolbar), 5);
  gtk_toolbar_set_space_size(GTK_TOOLBAR(toolbar), 5);
  gtk_widget_show(toolbar);
  gtk_fixed_put(GTK_FIXED(fixed), toolbar, x, y);
  return (toolbar); 
}

/*
** create_clist
*/
GtkWidget	*create_clist(GtkWidget *fixed, gint x, gint y,
			      gint width, gint height, gint columns,
			      gchar *titles[], GtkSelectionMode mode,
			      GtkShadowType shadow_type)
{
  GtkWidget	*clist;
  
  clist = gtk_clist_new_with_titles(columns, titles);
  gtk_widget_set_usize(clist, width, height);
  gtk_widget_show(clist);
  set_clist_events(clist);
  dragndrop_set_src(clist);
  gtk_clist_set_selection_mode(GTK_CLIST(clist), mode);
  gtk_clist_set_shadow_type(GTK_CLIST(clist), shadow_type);
  gtk_fixed_put(GTK_FIXED(fixed), clist, x, y);
  set_widget_coordinates(clist, x, y, width, height);
  return (clist);
}






