/*
** create_windows.c
** 
** Made by (Sebastien Thebert)
** Login   <theber_s@epita.fr>
** 
** Started on  Tue Apr  4 16:33:23 2000 Sebastien Thebert
** Last update Tue Apr  4 16:37:11 2000 Sebastien Thebert
*/
#include "main.h"

/*
** destroy_window
*/
void	destroy_window(GtkWidget *window)
{
  delete_in_completion_list(gtk_widget_get_name(window));
  hierarchy_remove(window);
  delete_window_file_code(window);
  gtk_widget_destroy(window);
}

/*
** Create a window
*/
GtkWidget	*create_window(gchar *title, gint width, gint height,
			       GtkWindowType type,
			       GtkWindowPosition position)
{
  GtkWidget	*win;
  GtkWidget	*fixed;
  
  fixed = gtk_fixed_new();
  gtk_widget_show(fixed);
  set_window_events(fixed);
  dragndrop_set_dest(fixed);
  win = gtk_window_new(type);
  gtk_window_set_title(GTK_WINDOW(win), title);
  gtk_container_add(GTK_CONTAINER(win), fixed);
  gtk_widget_show(win);
  gtk_widget_set_usize(win, width, height);
  gtk_window_set_position(GTK_WINDOW(win), position);
  gtk_signal_connect(GTK_OBJECT(win), "delete_event",
		     GTK_SIGNAL_FUNC(destroy_window), NULL);  
  GTK_WINDOW(win)->auto_shrink = FALSE;
  GTK_WINDOW(win)->allow_shrink = FALSE;
  return (win);
}

/*
** Create a file selection window
*/
GtkWidget	*create_file_selection(gchar *title, char *filename,
				       gboolean show_file_op_bt)
{
  GtkWidget	*file_select;
  
  file_select = gtk_file_selection_new(title);
  gtk_widget_show(file_select);
  if (!show_file_op_bt)
    gtk_file_selection_hide_fileop_buttons(GTK_FILE_SELECTION(file_select));
  gtk_file_selection_set_filename(GTK_FILE_SELECTION(file_select), filename);
  gtk_signal_connect(GTK_OBJECT(file_select), "delete_event",
		     GTK_SIGNAL_FUNC(destroy_window), NULL);
  return (file_select);
}

/*
** Create a color selection window
*/
GtkWidget	*create_color_selection(gchar *title, GtkUpdateType policy)
{
  GtkWidget	*color_select;
  
  color_select = gtk_color_selection_dialog_new(title);
  gtk_widget_show(color_select);
  gtk_color_selection_set_update_policy(GTK_COLOR_SELECTION
					(GTK_COLOR_SELECTION_DIALOG
					 (color_select)->colorsel),
					policy);
  gtk_signal_connect(GTK_OBJECT(color_select), "delete_event",
  		     GTK_SIGNAL_FUNC(destroy_window), NULL);
  return (color_select);
}

/*
** Create a font selection window
*/
GtkWidget	*create_font_selection(gchar *title)
{
  GtkWidget	*font_select;
  
  font_select = gtk_font_selection_dialog_new("Font Selection");
  gtk_widget_show(font_select);
  gtk_signal_connect(GTK_OBJECT(font_select), "delete_event",
  		     GTK_SIGNAL_FUNC(destroy_window), NULL);
  return (font_select);
}
