/*
** entry.c
** 
** Made by (Maxime VERNIER)
** Login   <vernie_m@epita.fr>
** 
** Started on  Tue Jun  1 15:37:48 1999 Maxime VERNIER
** Last update Sat Apr  1 02:27:39 2000 Sebastien Thebert
*/
#include "main.h"
#include "properties.h"
#include "restore.h"
#include "widget_events.h"

static void	cb_set_editable(GtkWidget *button, GtkWidget *widget)
{
  GtkWidget	*label;
  
  label = g_list_first(gtk_container_children(GTK_CONTAINER(button)))->data;
  if(GTK_TOGGLE_BUTTON(button)->active)
    {
      gtk_label_set_text(GTK_LABEL(label), "False"); 
      gtk_entry_set_editable(GTK_ENTRY(widget), FALSE);
    }
  else
    {
      gtk_label_set_text(GTK_LABEL(label), "True"); 
      gtk_entry_set_editable(GTK_ENTRY(widget), TRUE);
    }
  refresh_widget_code_from_properties(widget);
}

void	cb_set_length(GtkWidget *sender, GtkWidget *widget)
{
  if (GTK_IS_SPIN_BUTTON(sender))
    {
      guint16	value;
      
      value = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(sender));
      gtk_entry_set_max_length(GTK_ENTRY(widget), value);
      refresh_widget_code_from_properties(widget);
    }
}

void	cb_set_text(GtkWidget *sender, GtkWidget *widget)
{
  if (GTK_IS_ENTRY(sender))
    {
      GtkWidget		*entry;
      gchar		*text;
      guint16		value;
      
      entry = gtk_object_get_data(GTK_OBJECT(epingle->win_properties),
				  "ENTRY_LENGTH");
      value = GTK_ENTRY(sender)->text_length;
      gtk_spin_button_set_value(GTK_SPIN_BUTTON(entry), value); 
      text = gtk_entry_get_text(GTK_ENTRY(sender));
      gtk_entry_set_text(GTK_ENTRY(widget), text);
      refresh_widget_code_from_properties(widget);
    }
}

static void	cb_set_visibility(GtkWidget *button, GtkWidget *widget)
{
  GtkWidget *label;
  
  label = g_list_first(gtk_container_children(GTK_CONTAINER(button)))->data;
  if(GTK_TOGGLE_BUTTON(button)->active)
    {
      gtk_label_set_text(GTK_LABEL(label), "False"); 
      gtk_entry_set_visibility(GTK_ENTRY(widget), FALSE);
    }
  else
    {
      gtk_label_set_text(GTK_LABEL(label), "True"); 
      gtk_entry_set_visibility(GTK_ENTRY(widget), TRUE);
    }
  refresh_widget_code_from_properties(widget);
}

void		GtkEntry_properties(gint row, GtkWidget *widget)
{
  GtkWidget	*property;
  GtkWidget	*button;
  GtkWidget	*entry;
  GtkWidget	*table;
  gchar		*text;
  
  table = gtk_object_get_data(GTK_OBJECT(epingle->win_properties),
			      "properties"); 
  AddPropertyLabel(table, NB_WIDGET_PROP + 1, 
		   "Length", "Maximum length of the entry");
  entry = AddSpinProperty(table, NB_WIDGET_PROP + 1, 
			  GTK_ENTRY(widget)->text_max_length, 0,
			  TEXT_LENGTH, 1, 10, 0);
  gtk_object_set_data(GTK_OBJECT(epingle->win_properties),
		      "ENTRY_LENGTH", entry); 
  gtk_signal_connect(GTK_OBJECT(entry), "changed", 
		     GTK_SIGNAL_FUNC(cb_set_length), widget); 
  AddPropertyLabel(table, NB_WIDGET_PROP + 2, "Text",
		   "You can preload a text");
  entry = AddEntryProperty(table, NB_WIDGET_PROP + 2);
  gtk_object_set_data(GTK_OBJECT(epingle->win_properties), "text", entry); 
  text = gtk_entry_get_text(GTK_ENTRY(widget)); 
  gtk_entry_set_text(GTK_ENTRY(entry), text); 
  gtk_signal_connect(GTK_OBJECT(entry), "changed", 
		     GTK_SIGNAL_FUNC(cb_set_text), widget); 
  AddPropertyLabel(table, NB_WIDGET_PROP + 3, 
		   "Editable", "Is the entry editable ?");
  if ((GTK_ENTRY(widget)->editable).editable)
    button = AddToggleProperty(table, NB_WIDGET_PROP + 3, FALSE, "True");
  else
    button = AddToggleProperty(table, NB_WIDGET_PROP + 3, TRUE, "False");
  gtk_signal_connect(GTK_OBJECT(button), "toggled",
		     GTK_SIGNAL_FUNC(cb_set_editable), widget);
  AddPropertyLabel(table, NB_WIDGET_PROP + 4, 
		   "Visibility", "Is the text visible ?");
  if (GTK_EDITABLE(widget)->visible)
    property = AddToggleProperty(table, NB_WIDGET_PROP+4, FALSE, "True");
  else
    property = AddToggleProperty(table, NB_WIDGET_PROP+4, TRUE, "False");
  gtk_signal_connect(GTK_OBJECT(property), "toggled", 
		     GTK_SIGNAL_FUNC(cb_set_visibility), widget);
}

void	GtkEntry_save(FILE *fp, GtkWidget *widget, gint tab)
{
  write_num_property(fp, tab, "LENGTH", GTK_ENTRY(widget)->text_max_length);
  write_str_property(fp, tab, "ENTRY_TEXT",
		     gtk_entry_get_text(GTK_ENTRY(widget)));
  write_num_property(fp, tab, "EDITABLE", GTK_EDITABLE(widget)->editable);
  write_num_property(fp, tab, "VISIBILITY", GTK_EDITABLE(widget)->visible); 
}
