/*
** events.c for EPingle in 
** 
** Made by Sebastien Thebert
** Login   <theber_s@epita.fr>
** 
** Started on  Sun Apr  2 15:58:07 2000 Sebastien Thebert
** Last update Sun Apr  2 15:58:17 2000 Sebastien Thebert
*/
#include "main.h"

void		init_events(gint events_nb)
{
  GtkWidget	*notebook;
  GtkWidget	*table;
  GtkWidget	*label;
  
  notebook = gtk_object_get_data(GTK_OBJECT(epingle->win_properties),
				 "notebook"); 
  table = gtk_table_new(events_nb, 2, FALSE);
  gtk_table_set_col_spacing(GTK_TABLE(table), 0, 10);
  gtk_object_set_data(GTK_OBJECT(epingle->win_properties), "events", table); 
  gtk_widget_show(table);
  label = gtk_label_new("Events");
  gtk_notebook_append_page(GTK_NOTEBOOK(notebook), table, label);
}

void		entry_changed(GtkWidget *entry, gpointer event_type)
{
  GtkWidget	*widget;
  gchar		*text;
  gchar		*buffer;
  
  widget = get_current_widget();
  text = gtk_entry_get_text(GTK_ENTRY(entry));
  buffer = gtk_object_get_data(GTK_OBJECT(widget),
			       int_to_str((int)event_type));
  switch ((int)event_type)
    {
    case GtkWidget_show :
      create_event_code(entry, buffer, "show");
      break;
    case GtkWidget_hide :
      create_event_code(entry, buffer, "hide");
      break;
    case GtkWidget_button_press_event :
      create_event_code(entry, buffer, "button-press-event");
      break;
    case GtkWidget_button_release_event :
      create_event_code(entry, buffer, "button-release-event");
      break;
    case GtkWidget_motion_notify_event :
      create_event_code(entry, buffer, "motion-notify-event");
      break;
    case GtkWidget_destroy_event :
      create_event_code(entry, buffer, "destroy-event");
      break;  
    case GtkWidget_key_press_event :
      create_event_code(entry, buffer, "key-press-event");
      break;
    case GtkWidget_key_release_event :
      create_event_code(entry, buffer, "key-release-event");
      break;  
    case GtkWidget_enter_notify_event :
      create_event_code(entry, buffer, "enter-notify-event");
      break;
    case GtkWidget_leave_notify_event :
      create_event_code(entry, buffer, "leave-notify-event");
      break;   
    case GtkWidget_drag_drop :
      create_event_code(entry, buffer, "drag-drop");
      break; 
    case GtkWindow_set_focus :
      create_event_code(entry, buffer, "set-focus");
      break;
    case GtkButton_clicked :
      create_event_code(entry, buffer, "clicked");
      break;
    case GtkToggleButton_toggled :
      create_event_code(entry, buffer, "toggled");
      break;
    case GtkEditable_changed:
      create_event_code(entry, buffer, "changed");
      break;
    case GtkEditable_insert_text:
      create_event_code(entry, buffer, "insert-text");
      break;  
    case GtkEditable_delete_text:
      create_event_code(entry, buffer, "delete-text");
      break;  
    case GtkEditable_activate:
      create_event_code(entry, buffer, "activate");
      break;
    case GtkEditable_set_editable:
      create_event_code(entry, buffer, "set-editable");
      break;
    case GtkColorSelection_color_changed:
      create_event_code(entry, buffer, "color-changed");
      break;
    case GtkCList_select_row:
      create_event_code(entry, buffer, "select-row");
      break;
    case GtkCList_unselect_row:
      create_event_code(entry, buffer, "unselect-row");
      break;  
    case GtkCList_click_column:
      create_event_code(entry, buffer, "click-column");
      break;
    }
  if (buffer)
    free(buffer);
  buffer = xmalloc((strlen(text) + 1) * sizeof (*buffer));
  strcpy(buffer, text);
  gtk_object_set_data(GTK_OBJECT(widget),
		      int_to_str((int)event_type),  buffer);
}

void		add_event(GtkWidget *table, gint row, gint type)
{
  GtkWidget	*widget;
  GtkWidget	*label;
  GtkWidget	*event_box;
  GtkTooltips	*tooltips;
  GtkWidget	*entry = NULL;
  gchar		*text = NULL;
  
  widget = get_current_widget();
  event_box = gtk_event_box_new();
  tooltips = gtk_tooltips_new();
  entry = gtk_entry_new();
  switch (type)
    {
    case GtkWindow_set_focus:
      label = gtk_label_new("set_focus");
      gtk_container_add(GTK_CONTAINER(event_box), label);
      gtk_tooltips_set_tip(tooltips,event_box,"Window focus", NULL);
      gtk_signal_connect(GTK_OBJECT(entry), "changed",
			 GTK_SIGNAL_FUNC(entry_changed),
			 (gpointer) GtkWindow_set_focus);
      text = gtk_object_get_data(GTK_OBJECT(widget), 
				 (gchar *)int_to_str(GtkWindow_set_focus));
      break;
    case GtkButton_pressed:
      label = gtk_label_new("pressed");
      gtk_container_add(GTK_CONTAINER(event_box), label);
      gtk_tooltips_set_tip(tooltips,event_box,
			   "When the button has been pressed",
			   NULL);
      gtk_signal_connect(GTK_OBJECT(entry), "changed",
			 GTK_SIGNAL_FUNC(entry_changed),
			 (gpointer) GtkButton_pressed);
      text = gtk_object_get_data(GTK_OBJECT(widget), 
				 (gchar *)int_to_str(GtkButton_pressed));
      break;
    case GtkButton_released:
      label = gtk_label_new("released");
      gtk_container_add(GTK_CONTAINER(event_box), label);
      gtk_tooltips_set_tip(tooltips,event_box,
			   "When the button has been released and was previously pressed",
			   NULL);
      gtk_signal_connect(GTK_OBJECT(entry), "changed",
			 GTK_SIGNAL_FUNC(entry_changed),
			 (gpointer) GtkButton_released);
      text = gtk_object_get_data(GTK_OBJECT(widget), 
				 (gchar *)int_to_str(GtkButton_released));
      break;
    case GtkButton_clicked:
      label = gtk_label_new("clicked");
      gtk_container_add(GTK_CONTAINER(event_box), label);
      gtk_tooltips_set_tip(tooltips,event_box,
			   "When the button was pressed, and is inside the button when released",
			   NULL);
      gtk_signal_connect(GTK_OBJECT(entry), "changed",
			 GTK_SIGNAL_FUNC(entry_changed),
			 (gpointer) GtkButton_clicked);
      text = gtk_object_get_data(GTK_OBJECT(widget),
				 (gchar *)int_to_str(GtkButton_clicked));
      break;
    case GtkButton_enter:
      label = gtk_label_new("enter");
      gtk_container_add(GTK_CONTAINER(event_box), label);
      gtk_tooltips_set_tip(tooltips,event_box,
			   "When the cursor enters the button",
			   NULL); 
      gtk_signal_connect(GTK_OBJECT(entry), "changed",
			 GTK_SIGNAL_FUNC(entry_changed),
			 (gpointer) GtkButton_enter);
      text = gtk_object_get_data(GTK_OBJECT(widget),
				 (gchar *)int_to_str(GtkButton_enter));
      break;
    case GtkButton_leave:
      label = gtk_label_new("leave");
      gtk_container_add(GTK_CONTAINER(event_box), label);
      gtk_tooltips_set_tip(tooltips,event_box,
			   "When the cursor leaves the button",
			   NULL); 
      gtk_signal_connect(GTK_OBJECT(entry), "changed",
			 GTK_SIGNAL_FUNC(entry_changed),
			 (gpointer) GtkButton_leave);
      text = gtk_object_get_data(GTK_OBJECT(widget),
				 (gchar *)int_to_str(GtkButton_leave));
      break;
    case GtkToggleButton_toggled:
      label = gtk_label_new("toggled");
      gtk_container_add(GTK_CONTAINER(event_box), label);
      gtk_tooltips_set_tip(tooltips,event_box,
			   "When the button has been toggled",
			   NULL); 
      gtk_signal_connect(GTK_OBJECT(entry), "changed",
			 GTK_SIGNAL_FUNC(entry_changed),
			 (gpointer) GtkToggleButton_toggled);
      text = gtk_object_get_data(GTK_OBJECT(widget),
				 (gchar *)int_to_str(GtkToggleButton_toggled));
      break;
    case GtkEntry_set_text:
      label = gtk_label_new("set text");
      gtk_container_add(GTK_CONTAINER(event_box), label);
      gtk_tooltips_set_tip(tooltips,event_box,
			   "When the text is set",
			   NULL);  
      gtk_signal_connect(GTK_OBJECT(entry), "changed",
			 GTK_SIGNAL_FUNC(entry_changed),
			 (gpointer) GtkEntry_set_text);
      text = gtk_object_get_data(GTK_OBJECT(widget),
				 (gchar *)int_to_str(GtkEntry_set_text));
      break;  
    default:
      label = gtk_label_new("Unknown type of event");
    }
  gtk_widget_show(label);
  gtk_table_attach(GTK_TABLE(table), event_box, 0, 1, row - 1, row,
		   GTK_SHRINK|GTK_FILL|GTK_EXPAND, GTK_SHRINK|GTK_FILL, 0, 0);
  gtk_widget_show(event_box);
  if (text)
    gtk_entry_set_text(GTK_ENTRY(entry), text);
  gtk_table_attach(GTK_TABLE(table), entry, 1, 2, row - 1, row,
		   GTK_SHRINK|GTK_FILL|GTK_EXPAND, GTK_SHRINK|GTK_FILL, 0, 0);
  gtk_widget_show(entry);
}

void		add_common_widget_events(GtkWidget *table, GtkWidget *widget)
{
  GtkWidget	*event;
  gchar		*text;
  
  AddPropertyLabel(table, 1, "show", "When the widget is showed");
  event = AddEntryProperty(table, 1);
  if ((text = gtk_object_get_data(GTK_OBJECT(widget), 
				  int_to_str(GtkWidget_show))))
    gtk_entry_set_text(GTK_ENTRY(event), text); 
  gtk_signal_connect(GTK_OBJECT(event), "changed", 
		     GTK_SIGNAL_FUNC(entry_changed), 
		     (gpointer)GtkWidget_show); 
  AddPropertyLabel(table, 2, "hide", "When the widget is hidden");
  event = AddEntryProperty(table, 2);
  if ((text = gtk_object_get_data(GTK_OBJECT(widget), 
				  int_to_str(GtkWidget_hide))))
    gtk_entry_set_text(GTK_ENTRY(event), text); 
  gtk_signal_connect(GTK_OBJECT(event), "changed",
		     GTK_SIGNAL_FUNC(entry_changed), (gpointer)GtkWidget_hide);
  AddPropertyLabel(table, 3, "button-press-event", 
		   "When a button of the mouse is pressed");
  event = AddEntryProperty(table, 3);
  if ((text = gtk_object_get_data(GTK_OBJECT(widget), 
				  int_to_str(GtkWidget_button_press_event))))
    gtk_entry_set_text(GTK_ENTRY(event), text); 
  gtk_signal_connect(GTK_OBJECT(event), "changed", 
		     GTK_SIGNAL_FUNC(entry_changed), 
		     (gpointer)GtkWidget_button_press_event);
  AddPropertyLabel(table, 4, "button-release-event", 
		   "When a button of the mouse is released");
  event = AddEntryProperty(table, 4);
  if ((text = gtk_object_get_data(GTK_OBJECT(widget), 
				  int_to_str(GtkWidget_button_release_event))))
    gtk_entry_set_text(GTK_ENTRY(event), text); 
  gtk_signal_connect(GTK_OBJECT(event), "changed", 
		     GTK_SIGNAL_FUNC(entry_changed), 
		     (gpointer)GtkWidget_button_release_event);
  AddPropertyLabel(table, 5, "motion-notify-event", 
		   "When the mouse moves in the widget");
  event = AddEntryProperty(table, 5);
  if ((text = gtk_object_get_data(GTK_OBJECT(widget), 
				  int_to_str(GtkWidget_motion_notify_event))))
    gtk_entry_set_text(GTK_ENTRY(event), text); 
  gtk_signal_connect(GTK_OBJECT(event), "changed", 
		     GTK_SIGNAL_FUNC(entry_changed), 
		     (gpointer)GtkWidget_motion_notify_event);
  AddPropertyLabel(table, 6, "destroy-event", 
		   "When the widget is destroyed");
  event = AddEntryProperty(table, 6);
  if ((text = gtk_object_get_data(GTK_OBJECT(widget), 
				  int_to_str(GtkWidget_destroy_event))))
    gtk_entry_set_text(GTK_ENTRY(event), text); 
  gtk_signal_connect(GTK_OBJECT(event), "changed", 
		     GTK_SIGNAL_FUNC(entry_changed), 
		     (gpointer)GtkWidget_destroy_event);
  AddPropertyLabel(table, 7, "key-press-event", 
		   "When a key is pressed in the widget");
  event = AddEntryProperty(table, 7);
  if ((text = gtk_object_get_data(GTK_OBJECT(widget), 
				  int_to_str(GtkWidget_key_press_event))))
    gtk_entry_set_text(GTK_ENTRY(event), text); 
  gtk_signal_connect(GTK_OBJECT(event), "changed", 
		     GTK_SIGNAL_FUNC(entry_changed), 
		     (gpointer)GtkWidget_key_press_event); 
  AddPropertyLabel(table, 8, "key-release-event", 
		   "When a key is released in the widget");
  event = AddEntryProperty(table, 8);
  if ((text = gtk_object_get_data(GTK_OBJECT(widget), 
				  int_to_str(GtkWidget_key_release_event))))
    gtk_entry_set_text(GTK_ENTRY(event), text); 
  gtk_signal_connect(GTK_OBJECT(event), "changed", 
		     GTK_SIGNAL_FUNC(entry_changed), 
		     (gpointer)GtkWidget_key_release_event); 
  AddPropertyLabel(table, 9, "enter-notify-event", 
		   "When the mouse enters the widget");
  event = AddEntryProperty(table, 9);
  if ((text = gtk_object_get_data(GTK_OBJECT(widget), 
				  int_to_str(GtkWidget_enter_notify_event))))
    gtk_entry_set_text(GTK_ENTRY(event), text); 
  gtk_signal_connect(GTK_OBJECT(event), "changed", 
		     GTK_SIGNAL_FUNC(entry_changed), 
		     (gpointer)GtkWidget_enter_notify_event); 
  AddPropertyLabel(table, 10, "leave-notify-event", 
		   "When the mouse leaves the widget");
  event = AddEntryProperty(table, 10);
  if ((text = gtk_object_get_data(GTK_OBJECT(widget), 
				  int_to_str(GtkWidget_leave_notify_event))))
    gtk_entry_set_text(GTK_ENTRY(event), text); 
  gtk_signal_connect(GTK_OBJECT(event), "changed", 
		     GTK_SIGNAL_FUNC(entry_changed), 
		     (gpointer)GtkWidget_leave_notify_event); 
  AddPropertyLabel(table, 11, "drag-drop", 
		   "When the widget is dragged then dropped");
  event = AddEntryProperty(table, 11);
  if ((text = gtk_object_get_data(GTK_OBJECT(widget), 
				  int_to_str(GtkWidget_drag_drop))))
    gtk_entry_set_text(GTK_ENTRY(event), text); 
  gtk_signal_connect(GTK_OBJECT(event), "changed", 
		     GTK_SIGNAL_FUNC(entry_changed), 
		     (gpointer)GtkWidget_drag_drop); 
}

void		add_window_events(GtkWidget *table, GtkWidget *widget)
{
  GtkWidget	*event;
  gchar		*text;
  
  add_common_widget_events(table, widget);
  AddPropertyLabel(table, NB_WIDGET_EV + 1, "set-focus", "When focus is set");
  event = AddEntryProperty(table, NB_WIDGET_EV + 1);
  if ((text = gtk_object_get_data(GTK_OBJECT(widget), 
				  int_to_str(GtkWindow_set_focus))))
    gtk_entry_set_text(GTK_ENTRY(event), text); 
  gtk_signal_connect(GTK_OBJECT(event), "changed", 
		     GTK_SIGNAL_FUNC(entry_changed), 
		     (gpointer)GtkWindow_set_focus); 
}

void		GtkColorSelectionDialog_events(GtkWidget *table,
					       GtkWidget *widget)
{
  GtkWidget	*event;
  gchar		*text;
  
  add_window_events(table, widget);
  AddPropertyLabel(table, NB_WIN_EV + 1, "color-changed",
		   "When a color is changed");
  event = AddEntryProperty(table, NB_WIN_EV + 1);
  if((text = gtk_object_get_data(GTK_OBJECT(widget), 
				 int_to_str(GtkColorSelection_color_changed))))
    gtk_entry_set_text(GTK_ENTRY(event), text); 
  gtk_signal_connect(GTK_OBJECT(event), "changed", 
		     GTK_SIGNAL_FUNC(entry_changed), 
		     (gpointer)GtkColorSelection_color_changed); 
}

void	add_button_events(GtkWidget *table,GtkWidget *widget)
{
  add_common_widget_events(table, widget);
  add_event(table, NB_WIDGET_EV + 1, GtkButton_clicked);
}

void	add_toggle_button_events(GtkWidget *table, GtkWidget *widget)
{
  add_button_events(table, widget);
  add_event(table, NB_WIDGET_EV + 2, GtkToggleButton_toggled);
}

void		GtkEditable_events(GtkWidget *table, GtkWidget *widget)
{
  GtkWidget	*event;
  gchar		*text;
  
  add_common_widget_events(table, widget);
  AddPropertyLabel(table, NB_WIDGET_EV + 1, "changed",
		   "When the text is changed");
  event = AddEntryProperty(table, NB_WIDGET_EV + 1);
  if((text = gtk_object_get_data(GTK_OBJECT(widget), 
				 int_to_str(GtkEditable_changed))))
    gtk_entry_set_text(GTK_ENTRY(event), text); 
  gtk_signal_connect(GTK_OBJECT(event), "changed", 
		     GTK_SIGNAL_FUNC(entry_changed), 
		     (gpointer)GtkEditable_changed);
  AddPropertyLabel(table, NB_WIDGET_EV + 2, "insert-text",
		   "When a text is inserted");
  event = AddEntryProperty(table, NB_WIDGET_EV + 2);
  if((text = gtk_object_get_data(GTK_OBJECT(widget), 
				 int_to_str(GtkEditable_insert_text))))
    gtk_entry_set_text(GTK_ENTRY(event), text); 
  gtk_signal_connect(GTK_OBJECT(event), "changed", 
		     GTK_SIGNAL_FUNC(entry_changed), 
		     (gpointer)GtkEditable_insert_text);
  AddPropertyLabel(table, NB_WIDGET_EV + 3, "delete-text",
		   "When a text is deleted");
  event = AddEntryProperty(table, NB_WIDGET_EV + 3);
  if((text = gtk_object_get_data(GTK_OBJECT(widget), 
				 int_to_str(GtkEditable_delete_text))))
    gtk_entry_set_text(GTK_ENTRY(event), text); 
  gtk_signal_connect(GTK_OBJECT(event), "changed", 
		     GTK_SIGNAL_FUNC(entry_changed), 
		     (gpointer)GtkEditable_delete_text);
  AddPropertyLabel(table, NB_WIDGET_EV + 4, "activate",
		   "When the editable is activated");
  event = AddEntryProperty(table, NB_WIDGET_EV + 4);
  if((text = gtk_object_get_data(GTK_OBJECT(widget), 
				 int_to_str(GtkEditable_activate))))
    gtk_entry_set_text(GTK_ENTRY(event), text); 
  gtk_signal_connect(GTK_OBJECT(event), "changed", 
		     GTK_SIGNAL_FUNC(entry_changed), 
		     (gpointer)GtkEditable_activate);
  AddPropertyLabel(table, NB_WIDGET_EV + 5, "set-editable",
		   "When the editable is set editable (!)");
  event = AddEntryProperty(table, NB_WIDGET_EV + 5);
  if ((text = gtk_object_get_data(GTK_OBJECT(widget), 
				  int_to_str(GtkEditable_set_editable))))
    gtk_entry_set_text(GTK_ENTRY(event), text); 
  gtk_signal_connect(GTK_OBJECT(event), "changed", 
		     GTK_SIGNAL_FUNC(entry_changed), 
		     (gpointer)GtkEditable_set_editable); 
}

void		GtkCList_events(GtkWidget *table, GtkWidget *widget)
{
  GtkWidget	*event;
  gchar		*text;
  
  add_common_widget_events(table, widget);
  AddPropertyLabel(table, NB_WIDGET_EV + 1, "select-row",
		   "When a row of the clist is selected");
  event = AddEntryProperty(table, NB_WIDGET_EV + 1);
  if((text = gtk_object_get_data(GTK_OBJECT(widget), 
				 int_to_str(GtkCList_select_row))))
    gtk_entry_set_text(GTK_ENTRY(event), text); 
  gtk_signal_connect(GTK_OBJECT(event), "changed", 
		     GTK_SIGNAL_FUNC(entry_changed), 
		     (gpointer)GtkCList_select_row); 
  AddPropertyLabel(table, NB_WIDGET_EV + 2, "unselect-row",
		   "When a row of the clist is unselected");
  event = AddEntryProperty(table, NB_WIDGET_EV + 2);
  if((text = gtk_object_get_data(GTK_OBJECT(widget), 
				 int_to_str(GtkCList_unselect_row))))
    gtk_entry_set_text(GTK_ENTRY(event), text); 
  gtk_signal_connect(GTK_OBJECT(event), "changed", 
		     GTK_SIGNAL_FUNC(entry_changed), 
		     (gpointer)GtkCList_unselect_row);  
  AddPropertyLabel(table, NB_WIDGET_EV + 3, "click-column",
		   "When a column of the clist is clicked");
  event = AddEntryProperty(table, NB_WIDGET_EV + 3);
  if((text = gtk_object_get_data(GTK_OBJECT(widget), 
				 int_to_str(GtkCList_click_column))))
    gtk_entry_set_text(GTK_ENTRY(event), text); 
  gtk_signal_connect(GTK_OBJECT(event), "changed", 
		     GTK_SIGNAL_FUNC(entry_changed), 
		     (gpointer)GtkCList_click_column);  
}

void	add_entry_events(GtkWidget *table, GtkWidget *widget)
{
  GtkEditable_events(table, widget);
}










