/*  Epingle - Gtk+ User Interface Builder
 *  Copyright (C) 1999  Maxime Vernier
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 ** file.c
 ** 
 ** Made by (Maxime VERNIER)
 ** Login   <vernie_m@epita.fr>
 ** 
 ** Started on  Wed Mar 17 19:35:44 1999 Maxime VERNIER
** Last update Tue Apr  4 17:47:26 2000 Sebastien Thebert
*/
#include "main.h"

void	new_project(GtkWidget *sender, gpointer data)
{
  destroy_completion_list();
  init_completion_list();
  if (epingle->win_properties)
    {
      gtk_widget_destroy(epingle->win_properties);
      epingle->win_properties = NULL;
    }
  delete_old_project();
  create_main_file();
}

void		open_file_ok_sel(GtkWidget *button, GtkWidget *fs)
{
  GtkWidget	*widget; 
  gchar		*filename;
  char		*str;
  
  filename = gtk_file_selection_get_filename(GTK_FILE_SELECTION(fs));
  if ((str = strrchr(filename, '.')))
    {
      if (!strcmp(str, ".epingle"))
	restore_project(filename); 
      else
	if (!strcmp(str, ".xml"))
	  widget = restore_from_file(filename);
    }
  gtk_widget_destroy(fs);
  epingle->project_path = xmalloc(TEXT_LENGTH * sizeof (char));
  strncpy(epingle->project_path, filename, 
	  strlen(filename) - strlen(strrchr(filename, '/')));
}

void		open_file(GtkWidget *sender, gpointer data)
{
  GtkWidget	*filesel;
  
  filesel = gtk_file_selection_new("Open file");
  gtk_file_selection_hide_fileop_buttons(GTK_FILE_SELECTION(filesel));
  gtk_signal_connect(GTK_OBJECT(GTK_FILE_SELECTION (filesel)->ok_button),
		     "clicked", (GtkSignalFunc) open_file_ok_sel, filesel);
  gtk_signal_connect_object(GTK_OBJECT(GTK_FILE_SELECTION
				       (filesel)->cancel_button),
			    "clicked", 
			    GTK_SIGNAL_FUNC(gtk_widget_destroy),
			    GTK_OBJECT(filesel)); 
  gtk_widget_show(filesel);
}

void	save_and_quit_filesel(GtkWidget *button, GtkWidget *fs)
{
  gchar	*filename;
  
  filename = gtk_file_selection_get_filename(GTK_FILE_SELECTION(fs));
  if (!epingle->project_path)
    epingle->project_path = xmalloc(TEXT_LENGTH * sizeof (char));
  strcpy(epingle->project_path, filename);
  save_project(filename, epingle->window_list);
  gtk_widget_destroy(fs);
}

void		save_as(GtkWidget *sender, gpointer data)
{
  GtkWidget	*filesel;
  
  filesel = gtk_file_selection_new("Save project as...");
  gtk_file_selection_set_filename(GTK_FILE_SELECTION(filesel), 
				  epingle->project_name);
  gtk_signal_connect(GTK_OBJECT(GTK_FILE_SELECTION(filesel)->ok_button),
		     "clicked", 
		     GTK_SIGNAL_FUNC(save_and_quit_filesel), filesel);
  gtk_signal_connect_object(GTK_OBJECT(GTK_FILE_SELECTION
				       (filesel)->cancel_button),
			    "clicked", 
			    GTK_SIGNAL_FUNC(gtk_widget_destroy),
			    GTK_OBJECT(filesel));
  if (data && !strcmp(data, "quit"))
    gtk_signal_connect(GTK_OBJECT(filesel), "destroy",
		       gtk_main_quit, NULL);
  gtk_widget_show(filesel);
}

void	save(GtkWidget *sender, gpointer data)
{
  if (g_list_length(epingle->window_list) > 0)
    {
      if (epingle->project_path)
	{
	  save_project(); 
	  if (data && !strcmp(data, "quit"))
	    gtk_main_quit();
	}
      else
	if (data && !strcmp(data, "quit"))
	  save_as(NULL, "quit");
	else
	  save_as(NULL, NULL);
    }
}


/* A dialog box asking the user if he wants to save */

void		saving_dialog() 
{
  GtkWidget	*dialog;
  GtkWidget     *label; 
  GtkWidget	*yes_button;
  GtkWidget	*no_button;
  GtkWidget	*cancel_button;

  dialog = gtk_dialog_new();
  gtk_window_set_title(GTK_WINDOW(dialog), QUIT_TITLE);
  label = gtk_label_new(DO_YOU_WANT_TO_SAVE);
  yes_button = gtk_button_new_with_label("Yes");
  gtk_signal_connect(GTK_OBJECT(yes_button), "clicked",
		     GTK_SIGNAL_FUNC(save), "quit");
  gtk_container_add(GTK_CONTAINER(GTK_DIALOG(dialog)->action_area),
		    yes_button);
  no_button = gtk_button_new_with_label("No");
  gtk_signal_connect_object(GTK_OBJECT(no_button), "clicked",
			    GTK_SIGNAL_FUNC(gtk_main_quit), NULL);
  gtk_container_add(GTK_CONTAINER(GTK_DIALOG(dialog)->action_area),
		    no_button);
  cancel_button = gtk_button_new_with_label("Cancel");
  gtk_signal_connect_object(GTK_OBJECT(cancel_button), "clicked",
			    GTK_SIGNAL_FUNC(gtk_widget_destroy),
			    GTK_OBJECT(dialog));
  gtk_container_add(GTK_CONTAINER(GTK_DIALOG(dialog)->action_area),
		    cancel_button);
  gtk_container_set_border_width(GTK_CONTAINER(GTK_DIALOG(dialog)->vbox), 5);
  gtk_container_add(GTK_CONTAINER(GTK_DIALOG(dialog)->vbox),
		    label);
  gtk_widget_show_all(dialog);
}

void	epingle_quit(GtkWidget *sender, gpointer data)
{
  if (epingle->window_list)
    saving_dialog();
  else
    gtk_main_quit();
}



