/*
** file_selection.c
** 
** Made by (Maxime VERNIER)
** Login   <vernie_m@epita.fr>
** 
** Started on  Tue Jun  1 17:21:21 1999 Maxime VERNIER
** Last update Sat Apr  1 02:20:45 2000 Sebastien Thebert
*/
#include "main.h"
#include "properties.h"
#include "restore.h"
#include "window.h" 

void		cb_show_buttons(GtkWidget *button, GtkWidget *widget)
{
  GtkWidget	*label;
  
  label = g_list_first(gtk_container_children(GTK_CONTAINER(button)))->data;
  if(GTK_TOGGLE_BUTTON(button)->active)
    {
      gtk_label_set_text(GTK_LABEL(label), "No"); 
      gtk_file_selection_hide_fileop_buttons(GTK_FILE_SELECTION(widget));
    }
  else
    {
      gtk_label_set_text(GTK_LABEL(label), "Yes");
      gtk_file_selection_show_fileop_buttons(GTK_FILE_SELECTION(widget));
    }
  refresh_window_code(widget);
}

void	cb_change_filename(GtkWidget *sender, GtkWidget *entry)
{
  gchar *text;
  
  if (GTK_IS_ENTRY(sender))
    {
      text = gtk_entry_get_text(GTK_ENTRY(sender));
      gtk_entry_set_text(GTK_ENTRY(entry), text); 
    }
  refresh_window_code(get_current_widget());
}

void		GtkFileSelection_properties(GtkWidget *widget)
{
  GtkWidget	*entry, *button;
  gchar		*text;
  GtkWidget	*table;
  
  table = gtk_object_get_data(GTK_OBJECT(epingle->win_properties),
			      "properties"); 
  AddWindowProperties(widget);
  AddPropertyLabel(table, NB_WIN_PROP + 1, "File name",
		   "Default file name of the file selector");
  entry = AddEntryProperty(table, NB_WIN_PROP + 1);
  text = gtk_file_selection_get_filename(GTK_FILE_SELECTION(widget));
  gtk_entry_set_text(GTK_ENTRY(entry), text);
  gtk_object_set_data(GTK_OBJECT(epingle->win_properties), "FILENAME", entry);
  gtk_signal_connect(GTK_OBJECT(GTK_FILE_SELECTION(widget)->selection_entry),
		     "changed", GTK_SIGNAL_FUNC(cb_change_filename), entry); 
  AddPropertyLabel(table, NB_WIN_PROP + 2, "Show buttons?",
		   "Visibility of the file operation buttons");
  if(GTK_IS_WIDGET(GTK_FILE_SELECTION(widget)->fileop_c_dir)
     && GTK_IS_WIDGET(GTK_FILE_SELECTION(widget)->fileop_del_file)
     && GTK_IS_WIDGET(GTK_FILE_SELECTION(widget)->fileop_ren_file))
    button = AddToggleProperty(table, NB_WIN_PROP + 2, FALSE, "Yes");
  else
    button = AddToggleProperty(table, NB_WIN_PROP + 2, TRUE, "No");
  gtk_signal_connect(GTK_OBJECT(button), "toggled",
		     GTK_SIGNAL_FUNC(cb_show_buttons), widget); 
}

void		GtkFileSelection_save(FILE *fp, GtkWidget *widget, gint tab)
{
  gchar		*filename;
  gint		i;
  
  for(i = 1; i <= tab; i++)
    fprintf(fp, "\t");
  filename = gtk_file_selection_get_filename(GTK_FILE_SELECTION(widget));
  fprintf(fp, "<FILENAME>\t%s\n",filename);
  for(i = 1; i <= tab; i++)
    fprintf(fp, "\t");
  if(GTK_IS_WIDGET(GTK_FILE_SELECTION(widget)->fileop_c_dir)
     && GTK_IS_WIDGET(GTK_FILE_SELECTION(widget)->fileop_del_file)
     && GTK_IS_WIDGET(GTK_FILE_SELECTION(widget)->fileop_ren_file))
    fprintf(fp, "<SHOW_BUTTONS>\t%d\n", TRUE);
  else
    fprintf(fp, "<SHOW_BUTTONS>\t%d\n", FALSE);
}   

GtkWidget	*GtkFileSelection_restore(FILE *fp, gint tab)
{
  GtkWidget	*widget;
  text_property *property;
  gint		num;
  
  property = get_property(fp, tab);
  widget = gtk_file_selection_new(property->text);
  property = get_property(fp, tab);
  gtk_file_selection_set_filename(GTK_FILE_SELECTION(widget), property->text);
  num = get_num_property(fp, tab, FALSE);
  if (num)
    gtk_file_selection_show_fileop_buttons(GTK_FILE_SELECTION(widget));
  else
    gtk_file_selection_hide_fileop_buttons(GTK_FILE_SELECTION(widget));
  return (widget); 
}
