
#include <gtk/gtkfontsel.h>
#include "fontselection.h"

guint
simple_font_selection_get_type()
{
  static guint font_selection_type = 0;

  if(!font_selection_type)
    {
      GtkTypeInfo fontsel_info =
      {
	"GtkFontSelection",
	sizeof(GtkFontSelection),
	sizeof(GtkFontSelectionClass),
	(GtkClassInitFunc) gtk_font_selection_class_init,
	(GtkObjectInitFunc) simple_font_selection_init,
	(GtkArgSetFunc) NULL,
	(GtkArgGetFunc) NULL,
      };
      
      font_selection_type = gtk_type_unique (gtk_notebook_get_type(),
					     &fontsel_info);
    }
  
  return font_selection_type;
}

/*static*/ void
simple_font_selection_init(GtkFontSelection *fontsel, GtkWidget *box)
{
  GtkWidget *table, *label, *hbox, *hbox2;
  gint i, prop;
  gchar buffer[128];
  gchar *size;
  gint size_to_match;
  
  /* Initialize the GtkFontSelection struct. We do this here in case any
     callbacks are triggered while creating the interface. */
  fontsel->font = NULL;
  fontsel->font_index = -1;
  fontsel->style = -1;
  fontsel->metric = INITIAL_METRIC;
  fontsel->size = INITIAL_FONT_SIZE;
  fontsel->selected_size = INITIAL_FONT_SIZE;
  fontsel->scale_bitmapped_fonts = FALSE;

  for (prop = 0; prop < GTK_NUM_FONT_PROPERTIES; prop++)
    {
      fontsel->property_filters[prop] = NULL;
      fontsel->property_nfilters[prop] = 0;
    }
  
  for (prop = 0; prop < GTK_NUM_STYLE_PROPERTIES; prop++)
    fontsel->property_values[prop] = 0;
  
  fontsel->scroll_on_expose = TRUE;
  
  /* Create the main notebook page. */
  fontsel->main_vbox = gtk_vbox_new (FALSE, 4);
  gtk_widget_show (fontsel->main_vbox);
  gtk_container_border_width (GTK_CONTAINER (fontsel->main_vbox), 6);
  label = gtk_label_new("Font");
  gtk_widget_set_usize (label, 120, -1);

  gtk_box_pack_start(GTK_BOX(box), fontsel->main_vbox, TRUE, TRUE, 5);
  
/*  gtk_notebook_append_page (GTK_NOTEBOOK (fontsel),*/
/*			    fontsel->main_vbox, label);*/
  
  /*  Create the table of font, style & size. */
  table = gtk_table_new (3, 3, FALSE);
  gtk_widget_show (table);
  gtk_table_set_col_spacings(GTK_TABLE(table), 8);
  gtk_box_pack_start (GTK_BOX (fontsel->main_vbox), table, TRUE, TRUE, 0);

  fontsel->font_label = gtk_label_new("Font:");
  gtk_misc_set_alignment (GTK_MISC (fontsel->font_label), 0.0, 0.5);
  gtk_widget_show (fontsel->font_label);
  gtk_table_attach (GTK_TABLE (table), fontsel->font_label, 0, 1, 0, 1,
		    GTK_FILL, 0, 0, 0);
  label = gtk_label_new("Font Style:");
  gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
  gtk_widget_show (label);
  gtk_table_attach (GTK_TABLE (table), label, 1, 2, 0, 1,
		    GTK_FILL, 0, 0, 0);
  label = gtk_label_new("Size:");
  gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
  gtk_widget_show (label);
  gtk_table_attach (GTK_TABLE (table), label, 2, 3, 0, 1,
		    GTK_FILL, 0, 0, 0);
  
  fontsel->font_entry = gtk_entry_new();
  gtk_entry_set_editable(GTK_ENTRY(fontsel->font_entry), FALSE);
  gtk_widget_set_usize (fontsel->font_entry, 20, -1);
  gtk_widget_show (fontsel->font_entry);
  gtk_table_attach (GTK_TABLE (table), fontsel->font_entry, 0, 1, 1, 2,
		    GTK_FILL, 0, 0, 0);
  fontsel->font_style_entry = gtk_entry_new();
  gtk_entry_set_editable(GTK_ENTRY(fontsel->font_style_entry), FALSE);
  gtk_widget_set_usize (fontsel->font_style_entry, 20, -1);
  gtk_widget_show (fontsel->font_style_entry);
  gtk_table_attach (GTK_TABLE (table), fontsel->font_style_entry, 1, 2, 1, 2,
		    GTK_FILL, 0, 0, 0);
  fontsel->size_entry = gtk_entry_new();
  gtk_widget_set_usize (fontsel->size_entry, 20, -1);
  gtk_widget_show (fontsel->size_entry);
  gtk_table_attach (GTK_TABLE (table), fontsel->size_entry, 2, 3, 1, 2,
		    GTK_FILL, 0, 0, 0);
  gtk_signal_connect (GTK_OBJECT (fontsel->size_entry), "key_press_event",
		      (GtkSignalFunc) gtk_font_selection_size_key_press,
		      fontsel);

/*  Create the clists  */
  fontsel->font_clist = gtk_clist_new(1);
  gtk_clist_column_titles_hide (GTK_CLIST(fontsel->font_clist));
  gtk_clist_set_column_width (GTK_CLIST(fontsel->font_clist), 0, 300);
  gtk_clist_set_policy(GTK_CLIST(fontsel->font_clist), GTK_POLICY_ALWAYS,
		       GTK_POLICY_AUTOMATIC);
  gtk_widget_set_usize (fontsel->font_clist, FONT_LIST_WIDTH,
			FONT_LIST_HEIGHT);
  gtk_widget_show(fontsel->font_clist);
  gtk_table_attach (GTK_TABLE (table), fontsel->font_clist, 0, 1, 2, 3,
		    GTK_EXPAND | GTK_FILL,
		    GTK_EXPAND | GTK_FILL, 0, 0);

  fontsel->font_style_clist = gtk_clist_new(1);
  gtk_clist_column_titles_hide (GTK_CLIST(fontsel->font_style_clist));
  gtk_clist_set_column_width (GTK_CLIST(fontsel->font_style_clist), 0, 300);
  gtk_clist_set_policy(GTK_CLIST(fontsel->font_style_clist), GTK_POLICY_ALWAYS,
		       GTK_POLICY_AUTOMATIC);
  gtk_widget_set_usize (fontsel->font_style_clist, FONT_STYLE_LIST_WIDTH, -1);
  gtk_widget_show(fontsel->font_style_clist);
  gtk_table_attach (GTK_TABLE (table), fontsel->font_style_clist, 1, 2, 2, 3,
		    GTK_EXPAND | GTK_FILL,
		    GTK_EXPAND | GTK_FILL, 0, 0);

  fontsel->size_clist = gtk_clist_new(1);
  gtk_clist_column_titles_hide (GTK_CLIST(fontsel->size_clist));
  gtk_clist_set_policy(GTK_CLIST(fontsel->size_clist), GTK_POLICY_ALWAYS,
		       GTK_POLICY_AUTOMATIC);
  gtk_widget_set_usize (fontsel->size_clist, FONT_SIZE_LIST_WIDTH, -1);
  gtk_widget_show(fontsel->size_clist);
  gtk_table_attach (GTK_TABLE (table), fontsel->size_clist, 2, 3, 2, 3,
		    GTK_FILL, GTK_FILL, 0, 0);


  /* Insert the fonts. If there exist fonts with the same family but
     different foundries, then the foundry name is appended in brackets. */
  gtk_font_selection_insert_fonts(fontsel);

  gtk_signal_connect (GTK_OBJECT (fontsel->font_clist), "select_row",
		      GTK_SIGNAL_FUNC(gtk_font_selection_select_font),
		      fontsel);
  GTK_WIDGET_SET_FLAGS (fontsel->font_clist, GTK_CAN_FOCUS);
  gtk_signal_connect (GTK_OBJECT (fontsel->font_clist), "key_press_event",
		      GTK_SIGNAL_FUNC(gtk_font_selection_on_clist_key_press),
		      fontsel);
  gtk_signal_connect_after (GTK_OBJECT (fontsel->font_clist), "expose_event",
			    GTK_SIGNAL_FUNC(gtk_font_selection_expose_list),
			    fontsel);

  gtk_signal_connect (GTK_OBJECT (fontsel->font_style_clist), "select_row",
		      GTK_SIGNAL_FUNC(gtk_font_selection_select_style),
		      fontsel);
  GTK_WIDGET_SET_FLAGS (fontsel->font_style_clist, GTK_CAN_FOCUS);
  gtk_signal_connect (GTK_OBJECT (fontsel->font_style_clist),
		      "key_press_event",
		      GTK_SIGNAL_FUNC(gtk_font_selection_on_clist_key_press),
		      fontsel);

  /* Insert the standard font sizes */
  gtk_clist_freeze (GTK_CLIST(fontsel->size_clist));
  size_to_match = INITIAL_FONT_SIZE;
  if (INITIAL_METRIC == POINTS_METRIC)
    size_to_match = size_to_match / 10;
  for (i = 0; i < sizeof(font_sizes) / sizeof(font_sizes[0]); i++)
    {
      sprintf(buffer, "%i", font_sizes[i]);
      size = buffer;
      gtk_clist_append(GTK_CLIST(fontsel->size_clist), &size);
      if (font_sizes[i] == size_to_match)
	{
	  gtk_clist_select_row(GTK_CLIST(fontsel->size_clist), i, 0);
	  gtk_entry_set_text(GTK_ENTRY(fontsel->size_entry), buffer);
	}
    }
  gtk_clist_thaw (GTK_CLIST(fontsel->size_clist));

  gtk_signal_connect (GTK_OBJECT (fontsel->size_clist), "select_row",
		      GTK_SIGNAL_FUNC(gtk_font_selection_select_size),
		      fontsel);
  GTK_WIDGET_SET_FLAGS (fontsel->size_clist, GTK_CAN_FOCUS);
  gtk_signal_connect (GTK_OBJECT (fontsel->size_clist), "key_press_event",
		      GTK_SIGNAL_FUNC(gtk_font_selection_on_clist_key_press),
		      fontsel);


  /* create the Filter, Scale Bitmaps & Metric buttons */
  hbox = gtk_hbox_new(FALSE, 8);
  gtk_widget_show (hbox);
  gtk_box_pack_start (GTK_BOX (fontsel->main_vbox), hbox, FALSE, TRUE, 0);
  
  fontsel->scaled_bitmaps_button
    = gtk_check_button_new_with_label("Allow scaled bitmap fonts");
  gtk_widget_show(fontsel->scaled_bitmaps_button);
  gtk_box_pack_start (GTK_BOX (hbox), fontsel->scaled_bitmaps_button,
		      FALSE, FALSE, 0);
  if (!fontsel_info->scaled_bitmaps_available)
    gtk_widget_set_sensitive (fontsel->scaled_bitmaps_button, FALSE);
  gtk_signal_connect (GTK_OBJECT (fontsel->scaled_bitmaps_button), "clicked",
		      GTK_SIGNAL_FUNC(gtk_font_selection_toggle_scaled_bitmaps),
		      fontsel);
  
  hbox2 = gtk_hbox_new(FALSE, 0);
  gtk_widget_show (hbox2);
  gtk_box_pack_end (GTK_BOX (hbox), hbox2, FALSE, FALSE, 0);
  
  label = gtk_label_new("Metric:");
  gtk_widget_show (label);
  gtk_box_pack_start (GTK_BOX (hbox2), label, FALSE, TRUE, 8);
  
  fontsel->points_button = gtk_radio_button_new_with_label(NULL, "Points");
  gtk_widget_show (fontsel->points_button);
  gtk_box_pack_start (GTK_BOX (hbox2), fontsel->points_button, FALSE, TRUE, 0);
  if (INITIAL_METRIC == POINTS_METRIC)
    gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(fontsel->points_button),
				TRUE);
  
  fontsel->pixels_button = gtk_radio_button_new_with_label_from_widget(GTK_RADIO_BUTTON(fontsel->points_button), "Pixels");
  gtk_widget_show (fontsel->pixels_button);
  gtk_box_pack_start (GTK_BOX (hbox2), fontsel->pixels_button, FALSE, TRUE, 0);
  if (INITIAL_METRIC == PIXELS_METRIC)
    gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(fontsel->pixels_button),
				TRUE);
  
  gtk_signal_connect(GTK_OBJECT(fontsel->points_button), "toggled",
		     (GtkSignalFunc) gtk_font_selection_metric_callback,
		     fontsel);
  gtk_signal_connect(GTK_OBJECT(fontsel->pixels_button), "toggled",
		     (GtkSignalFunc) gtk_font_selection_metric_callback,
		     fontsel);
  
  /* Create the message area */
  fontsel->message_label = gtk_label_new("");
  gtk_widget_show (fontsel->message_label);
  gtk_box_pack_start (GTK_BOX (fontsel->main_vbox), fontsel->message_label, 
		      FALSE, FALSE, 0);
  
}

GtkWidget *
simple_font_selection_new()
{
  GtkFontSelection *fontsel;
  
  fontsel = gtk_type_new (gtk_font_selection_get_type ());
  
  return GTK_WIDGET (fontsel);
}


