/*
** make_makefile.c
** 
** Made by (Morisseau Bertrand)
** Login   <moriss_b@epita.fr>
** 
** Started on  Mon Apr 19 14:44:22 1999 Morisseau Bertrand
** Last update Mon Apr  3 22:47:33 2000 Sebastien Thebert
*/
#include "main.h"

void	make_global(FILE* fp);
void	make_optional(FILE* fp);
void	make_macro(FILE* fp);
void	make_instructions(FILE* fp);

extern int	opt_wall, opt_debug, opt_optimization;

/*
** generate_makefile
*/
void	generate_makefile()
{
  FILE	*fp;
  char	*filename;
  
  filename = xmalloc(sizeof (char) * FN_LENGTH);
  strcpy(filename, epingle->project_path);
  strcat(filename, "/Makefile_tmp");
  fp = fopen(filename, "w+");
  make_global(fp);
  make_optional(fp);
  make_macro(fp);
  make_instructions(fp);
  fclose(fp);
  free(filename);
}

/*
** make_global
*/
void		make_global(FILE *fp)
{
  GtkWidget	*widget;
  gint		i;
  
  fprintf(fp, "#\n# Makefile\n#\n#\n\n");
  fprintf(fp, "NAME\t= %s\n", epingle->project_name);
  fprintf(fp, "SRC\t= %s.c ", epingle->project_name);
  for (i = 0; i < g_list_length(epingle->window_list); i++)
    {
      widget = g_list_nth(epingle->window_list, i)->data;
      fprintf(fp, "%s.c ", gtk_widget_get_name(widget));
    }
  fprintf(fp, "\t# List of .c \n");
  fprintf(fp, "INCL\t= ");
  fprintf(fp, "\t# List of .h \n");
  fprintf(fp, "BAK\t= *~ *core\n\n");
}

/*
** make_optional
*/
void	make_optional(FILE *fp)
{
  char	*options;
  char	*line;
  
  line = xmalloc(sizeof (char) * LENGTH);
  options = xmalloc(sizeof (char) * LENGTH);
  strcpy(options, "");
  if (opt_wall)
    strcat(options, "-Wall ");
  if (opt_optimization == 1)
    strcat(options, "-O1 ");
  else if (opt_optimization == 2)
    strcat(options, "-O2 ");
  if (opt_debug == 1)
    strcat(options, "-Debug ");
  fprintf(fp, "#\n# Optional Add\n#\n");
  fprintf(fp, "IPATH\t= # -I \n");
  strcpy(line, "OBJOPT\t= ");
  strcat(line, options);
  strcat(line, "\t# Option For Obj\n");
  fprintf(fp, line);
  strcpy(line, "EXEOPT\t= ");
  strcat(line, options);
  strcat(line, "\t# Option For Exe\n");
  fprintf(fp, line);
  fprintf(fp, "LPATH\t= `gtk-config --libs` \t# -L \n\n");
  free(line);
  free(options);
}

/*
** make_macro
*/
void	make_macro(FILE *fp)
{
  fprintf(fp, "#\n# Macro Definitions\n#\n");
  fprintf(fp, "CC\t= gcc\n");
  fprintf(fp, "OBJS\t= $(SRC:.c=.o)\n");
  fprintf(fp, "RM\t= /bin/rm -f\n");
  fprintf(fp, "CFLAGS\t= $(OBJOPT) `gtk-config --cflags`\n");
  fprintf(fp, "LDFLAGS\t= $(EXEOPT) $(LPATH)\n\n");
}

/*
** make_instructions
*/
void	make_instructions(FILE *fp)
{
  fprintf(fp, "#\n# Basic Compile Instructions\n#\n");
  fprintf(fp, "$(NAME): $(OBJS) $(SRC) $(INCL)\n");
  fprintf(fp, "\t$(CC) $(OBJS) $(LDFLAGS) -o $(NAME)\n");
  fprintf(fp, "clean:\n\t-$(RM) $(NAME) $(OBJS) $(BAK)\n\n");
  fprintf(fp, ".c.o:\n\t$(CC) $(CFLAGS) -c $<\n\n");
}



				       
				       
				       
				       
				       
				       
				       
				       
				       
				       


