/*
** list_manager.c
** 
** Made by (Maxime VERNIER)
** Login   <vernie_m@epita.fr>
** 
** Started on  Tue Jun  8 23:12:10 1999 Maxime VERNIER
** Last update Wed Jun 16 02:37:59 1999 maxime vernier
*/

#include "main.h"

static void
list_changed(GtkWidget *listbox)
{
  GtkWidget	*widget;
  GtkWidget	*menu;
  gint		type;

  widget = get_current_widget();
  type = get_widget_type(widget); 
  if(!GTK_CLIST(listbox)->row_list)
    {
      switch(type)
	{
	case COMBO: 
	  gtk_list_clear_items(GTK_LIST(GTK_COMBO(widget)->list),0,-1);
	  break;
	case OPTION_MENU:
	  menu = gtk_option_menu_get_menu(GTK_OPTION_MENU(widget));
	  gtk_widget_destroy(menu); 
	  break;
	}
    }
  else
    {
      gint i;
      GList *list = NULL;
      for(i=1;i<=GTK_CLIST(listbox)->rows;i++)
	{
	  gchar		*text;
	  gtk_clist_get_text(GTK_CLIST(listbox),i-1,0,&text);
	  list = g_list_append(list,text);
	}
      switch(type)
	{
	case COMBO:
	  gtk_combo_set_popdown_strings(GTK_COMBO(widget), list);
	  break;
	case OPTION_MENU:
	  menu = gtk_option_menu_get_menu(GTK_OPTION_MENU(widget));
	  if(menu)
	    gtk_widget_destroy(menu); 
	  menu = gtk_menu_new();
	  gtk_option_menu_set_menu(GTK_OPTION_MENU(widget), menu);
	  for(i=0; i<g_list_length(list); i++)
	    {
	      GtkWidget *menu_item;
	      gchar	*label;
	  
	      label = g_list_nth(list, i)->data;
	      menu_item = gtk_menu_item_new_with_label(label);
	      gtk_menu_append(GTK_MENU(menu), menu_item);
	      gtk_widget_show(menu_item);
	    }
	  break;
	}
    }
}

static void 
add_list_item_cb(GtkWidget *sender, GtkWidget *listbox)
{
  GtkWidget	*entry;
  gchar		*text;
  
  if(GTK_IS_BUTTON(sender))
    entry = gtk_object_get_data(GTK_OBJECT(sender),"entry");
  else
    entry = sender;
  text = gtk_entry_get_text(GTK_ENTRY(entry));
  gtk_clist_append(GTK_CLIST(listbox),&text);
  gtk_entry_set_text(GTK_ENTRY(entry),"");
  list_changed(listbox);
}

static void 
del_list_item_cb(GtkWidget *sender, GtkWidget *list)
{
  while(GTK_CLIST(list)->selection)
    gtk_clist_remove(GTK_CLIST(list), 
		     GPOINTER_TO_INT(GTK_CLIST(list)->selection->data));
  list_changed(list);
}

static void 
clr_list_items_cb(GtkWidget *sender, GtkWidget *list)
{
  gtk_clist_clear(GTK_CLIST(list));
  list_changed(list);
}

GtkWidget *
list_manager_new()
{
  GtkWidget	*widget;
  GtkWidget	*frame;
  GtkWidget	*table;
  GtkWidget	*entry;
  GtkWidget	*button;
  GtkWidget	*listbox;
  GtkWidget	*menu; 
  GList		*node, *list = NULL;
  gint		type;
  
  widget = get_current_widget();
  frame = gtk_frame_new("List of items");
  table = gtk_table_new(2,3,FALSE);
  listbox = gtk_clist_new(1);
  gtk_clist_set_selection_mode(GTK_CLIST(listbox), GTK_SELECTION_MULTIPLE);
  type = get_widget_type(widget);
  switch(type)
    {
    case COMBO:
      list = gtk_container_children(GTK_CONTAINER(GTK_COMBO(widget)->list));
      break;
    case OPTION_MENU:
      menu = gtk_option_menu_get_menu(GTK_OPTION_MENU(widget));
      if(menu)
	list = GTK_MENU_SHELL(menu)->children;
      else
	list = NULL;
      break;
    }
  for(node=list;node;node=node->next)
    {
      GList		*children = NULL;
      GtkWidget		*label;
      gchar		*text;

      children = gtk_container_children(GTK_CONTAINER(node->data)); 
      if(children)
	{
	  label = g_list_first(children)->data;
	  gtk_label_get(GTK_LABEL(label), &text);
	  gtk_clist_append(GTK_CLIST(listbox),&text);
	}
    }
  gtk_table_attach(GTK_TABLE(table),listbox,0,1,1,3,
		   GTK_SHRINK|GTK_FILL|GTK_EXPAND, GTK_SHRINK|GTK_FILL, 0, 0);
  gtk_widget_show(listbox);
  entry = gtk_entry_new();
  gtk_signal_connect(GTK_OBJECT(entry),"activate",
		     GTK_SIGNAL_FUNC(add_list_item_cb), listbox);
  gtk_table_attach(GTK_TABLE(table),entry,0,1,0,1,
		   GTK_SHRINK|GTK_FILL|GTK_EXPAND, GTK_SHRINK|GTK_FILL, 0, 0);
  gtk_widget_show(entry);
  button = gtk_button_new_with_label("Add");
  gtk_object_set_data(GTK_OBJECT(button), "entry", entry);
  gtk_signal_connect(GTK_OBJECT(button),"clicked",
		     GTK_SIGNAL_FUNC(add_list_item_cb), listbox);
  gtk_table_attach(GTK_TABLE(table),button,1,2,0,1,
		      GTK_SHRINK|GTK_FILL|GTK_EXPAND, GTK_SHRINK|GTK_FILL, 0, 0);
  gtk_widget_show(button);
  button = gtk_button_new_with_label("Del");
  gtk_signal_connect(GTK_OBJECT(button),"clicked",
		     GTK_SIGNAL_FUNC(del_list_item_cb),listbox);
  gtk_table_attach(GTK_TABLE(table),button,1,2,1,2,
		   GTK_SHRINK|GTK_FILL|GTK_EXPAND, GTK_SHRINK|GTK_FILL, 0, 0);
  gtk_widget_show(button);
  button = gtk_button_new_with_label("Clr");
  gtk_signal_connect(GTK_OBJECT(button),"clicked",
		     GTK_SIGNAL_FUNC(clr_list_items_cb),listbox);
  gtk_table_attach(GTK_TABLE(table),button,1,2,2,3,
		   GTK_SHRINK|GTK_FILL|GTK_EXPAND, GTK_SHRINK|GTK_FILL, 0, 0);
  gtk_widget_show(button);
  gtk_container_add(GTK_CONTAINER(frame),table);
  gtk_widget_show(table);
  return frame;
}

