/*
** main_window.c
** 
** Made by (Sebastien Thebert)
** Login   <theber_s@epita.fr>
** 
** Started on  Thu Jan 20 17:03:16 2000 Sebastien Thebert
** Last update Wed Apr  5 13:20:48 2000 Sebastien Thebert
*/
#include "main.h"

GtkWidget	*gl_sbar;
guint		gl_sbar_context_id;
GtkRadioButton	*last_radio_button;
gint		widget_selected;

struct alignment	align;

/*
** select widget to put
*/
void		select_widget_to_put(GtkWidget *sender, gpointer type)
{
  t_put_fct	*put_fct;
  int		i;
  
  last_radio_button = NULL;
  switch((int)type)
    {
    case LEFT_ALIGN :	case RIGHT_ALIGN :
    case TOP_ALIGN :	case BOTTOM_ALIGN :
    case WIDTH_ALIGN :	case HEIGHT_ALIGN :
      align.pos = (int)type;
      align.coord = -1;
      break;
    default :
      align.pos = align.coord = -1;
      break;
    }
  gtk_statusbar_pop(GTK_STATUSBAR(gl_sbar), gl_sbar_context_id);
  for (i = 0; i < 20; i++)
    {
      put_fct = &put_fct_array[i];
      if (put_fct->widget == (int)type)
	gtk_statusbar_push(GTK_STATUSBAR(gl_sbar), gl_sbar_context_id,
			   put_fct->msg);
    }
  widget_selected = (int)type;
}

/*
** Create Menu Item
*/
GtkWidget	*create_menu_item(char *name, void *func, int key, char *tips)
{
  GtkWidget	*m_item;
  GtkTooltips	*tooltips;
  GtkAccelGroup *accelerator_group;
  
  accelerator_group = gtk_accel_group_new();
  gtk_accel_group_attach(accelerator_group, GTK_OBJECT(epingle->main_window));
  m_item = gtk_menu_item_new_with_label(name);
  gtk_signal_connect(GTK_OBJECT(m_item), "activate",
		     GTK_SIGNAL_FUNC(func), NULL);
  if (key)
    gtk_widget_add_accelerator(m_item, "activate", accelerator_group, key,
			       GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
  gtk_widget_show(m_item);
  if (tips)
    {
      tooltips = gtk_tooltips_new();
      gtk_tooltips_set_tip(tooltips, m_item, tips, NULL);
    }
  return (m_item);
}

/*
** Create the menu "File" of the Main Window
*/
void		file_menu(GtkWidget *menu_bar)
{
  GtkWidget	*root_menu;
  GtkWidget	*menu;
  GtkWidget	*m_item;
  
  root_menu = gtk_menu_item_new_with_label("File");
  gtk_widget_show(root_menu);
  menu = gtk_menu_new();
  m_item = create_menu_item("New", new_project, GDK_N, "New Project");
  gtk_menu_append(GTK_MENU(menu), m_item);
  m_item = create_menu_item("Open", open_file, GDK_O, "Open Project");
  gtk_menu_append(GTK_MENU(menu), m_item);
  m_item = create_menu_item("Save", save, GDK_S, "Save Project");
  gtk_menu_append(GTK_MENU(menu), m_item);
  m_item = create_menu_item("Save as", save_as, 0,
			    "Save Project with a new name");
  gtk_menu_append(GTK_MENU(menu), m_item);
  m_item = create_menu_item("Quit", epingle_quit, GDK_Q, 0);
  gtk_menu_append(GTK_MENU(menu), m_item);
  gtk_menu_item_set_submenu(GTK_MENU_ITEM(root_menu), menu);
  gtk_menu_bar_append(GTK_MENU_BAR(menu_bar), root_menu);
}

/*
** Create the menu "Edition" of the Main Window
*/
void		edition_menu(GtkWidget *menu_bar)
{
  GtkWidget	*root_menu;
  GtkWidget	*menu;
  GtkWidget	*m_item;
  
  root_menu = gtk_menu_item_new_with_label("Edition");
  gtk_widget_show(root_menu);
  menu = gtk_menu_new();
  m_item = create_menu_item("Preferences", edit_preferences, GDK_P, 0);
  gtk_menu_append(GTK_MENU(menu), m_item);
  gtk_menu_item_set_submenu(GTK_MENU_ITEM(root_menu), menu);
  gtk_menu_bar_append(GTK_MENU_BAR(menu_bar), root_menu);
}

/*
** Create the menu "Compilation" of the Main Window
*/
void		compilation_menu(GtkWidget *menu_bar)
{
  GtkWidget	*root_menu;
  GtkWidget	*menu;
  GtkWidget	*m_item;
  
  root_menu = gtk_menu_item_new_with_label("Compilation");
  gtk_widget_show(root_menu);
  menu = gtk_menu_new();
  m_item = create_menu_item("Options", compilation_options, 0, 0);
  gtk_menu_append(GTK_MENU(menu), m_item);
  m_item = create_menu_item("Compilation", compilation, GDK_C, 0);
  gtk_menu_append(GTK_MENU(menu), m_item);
  m_item = create_menu_item("Execution", execution, GDK_X, 0);
  gtk_menu_append(GTK_MENU(menu), m_item);
  gtk_menu_item_set_submenu(GTK_MENU_ITEM(root_menu), menu);
  gtk_menu_bar_append(GTK_MENU_BAR(menu_bar), root_menu);
}

/*
** Create the menu "Help" of the Main Window
*/
void		help_menu(GtkWidget *menu_bar)
{
  GtkWidget	*root_menu;
  GtkWidget	*menu;
  GtkWidget	*m_item;
  
  root_menu = gtk_menu_item_new_with_label("Help");
  gtk_widget_show(root_menu);
  menu = gtk_menu_new();
  m_item = create_menu_item("About", about, 0, 0);
  gtk_menu_append(GTK_MENU(menu), m_item);
  m_item = create_menu_item("Legal", legal, 0, 0);
  gtk_menu_append(GTK_MENU(menu), m_item);
  gtk_menu_item_set_submenu(GTK_MENU_ITEM(root_menu), menu);
  gtk_menu_bar_append(GTK_MENU_BAR(menu_bar), root_menu);
}

/*
*********************************
** Create the Main Window menu **
*********************************
*/
void		create_main_window_menu(GtkWidget *vbox)
{
  GtkWidget	*menu_bar;
  
  menu_bar = gtk_menu_bar_new();
  gtk_box_pack_start(GTK_BOX(vbox), menu_bar, FALSE, FALSE, 2);
  gtk_widget_show(menu_bar);
  file_menu(menu_bar); 
  edition_menu(menu_bar);
  compilation_menu(menu_bar);
  help_menu(menu_bar);
}


/*
** Add pixmap in a button
*/
void		add_pixmap(GtkWidget *bt,
			   char *pixmap_file,
			   GtkWidget *win,
			   GdkBitmap *mask,
			   GtkStyle *style)
{
  GtkWidget	*pixmap;
  GdkPixmap	*gdk_pixmap;
  
  gdk_pixmap = gdk_pixmap_create_from_xpm(win->window, &mask,
					  &style->bg[GTK_STATE_NORMAL],
					  pixmap_file);
  pixmap = gtk_pixmap_new(gdk_pixmap, mask);
  gtk_widget_show(pixmap);
  gtk_container_add(GTK_CONTAINER(bt), pixmap);
}

/*
** Create a button with a pixmap
*/
GtkWidget	*create_pixmap_bt(char *filename,
				  GdkBitmap *mask,
				  GtkStyle *style,
				  GtkSignalFunc func,
				  gpointer pointer)
{
  GtkWidget	*bt;
  
  bt = gtk_button_new();
  gtk_signal_connect(GTK_OBJECT(bt), "clicked", func, pointer);
  gtk_widget_set_usize(bt, 36, 36);
  /*  gtk_widget_set_usize(bt, 56, 56);*/
  gtk_widget_show(bt);
  add_pixmap(bt, filename, epingle->main_window, mask, style);
  return (bt);
}

/*
** Create the "Windows" Notebook of the Main Window
*/
void		create_notebook_for_windows(GtkWidget	*notebook,
					    GtkTooltips *tooltips,
					    GdkBitmap	*mask,
					    GtkStyle	*style)
{
  GtkWidget	*label;
  GtkWidget	*bt;
  GtkWidget	*hbox;
  
  hbox = gtk_hbox_new(FALSE, 0);
  bt = create_pixmap_bt("./xpm/window2.xpm", mask, style, put_window, NULL);
  gtk_tooltips_set_tip(tooltips, bt, "Create Classic Window", NULL);
  gtk_box_pack_start(GTK_BOX(hbox), bt, FALSE, FALSE, 5);
  bt = create_pixmap_bt("./xpm/file_selector2.xpm", mask, style,
			put_file_select, NULL);
  gtk_tooltips_set_tip(tooltips, bt, "Create File Selector", NULL);
  gtk_box_pack_start(GTK_BOX(hbox), bt, FALSE, FALSE, 5);
  bt = create_pixmap_bt("./xpm/color_selector2.xpm", mask, style,
			put_color_select, NULL);
  gtk_tooltips_set_tip(tooltips, bt, "Create Color Selector", NULL);
  gtk_box_pack_start(GTK_BOX(hbox), bt, FALSE, FALSE, 5);
  bt = create_pixmap_bt("./xpm/font_selector2.xpm", mask, style,
			put_font_select, NULL);
  gtk_tooltips_set_tip(tooltips, bt, "Create Font Selector", NULL);
  gtk_box_pack_start(GTK_BOX(hbox), bt, FALSE, FALSE, 5);
  bt = create_pixmap_bt("./xpm/dialog2.xpm", mask, style, put_dialog, NULL);
  gtk_tooltips_set_tip(tooltips, bt, "Create Dialog Window", NULL);
  gtk_box_pack_start(GTK_BOX(hbox), bt, FALSE, FALSE, 5);
  gtk_widget_show(hbox);
  label = gtk_label_new("Windows");
  gtk_notebook_append_page(GTK_NOTEBOOK(notebook), hbox, label);
}

/*
** Create the "Buttons" Notebook of the Main Window
*/
void		create_notebook_for_buttons(GtkWidget	*notebook,
					    GtkTooltips *tooltips,
					    GdkBitmap	*mask,
					    GtkStyle	*style)
{
  GtkWidget	*label;
  GtkWidget	*bt;
  GtkWidget	*hbox;
  
  hbox = gtk_hbox_new(FALSE,0);
  bt = create_pixmap_bt("./xpm/bt_classic2.xpm", mask, style,
			select_widget_to_put, (gpointer)BUTTON);
  gtk_tooltips_set_tip(tooltips, bt, "Create Classic Button", NULL);
  gtk_box_pack_start(GTK_BOX(hbox), bt, FALSE, FALSE, 5);
  bt = create_pixmap_bt("./xpm/bt_toggle2.xpm", mask, style,
			select_widget_to_put, (gpointer)TOGGLE_BUTTON);
  gtk_tooltips_set_tip(tooltips, bt, "Create Toggle Button", NULL);
  gtk_box_pack_start(GTK_BOX(hbox), bt, FALSE, FALSE, 5);
  bt = create_pixmap_bt("./xpm/bt_check2.xpm", mask, style,
			select_widget_to_put, (gpointer)CHECK_BUTTON);
  gtk_tooltips_set_tip(tooltips, bt, "Create Check Button", NULL);
  gtk_box_pack_start(GTK_BOX(hbox), bt, FALSE, FALSE, 5);
  bt = create_pixmap_bt("./xpm/bt_radio2.xpm", mask, style,
			select_widget_to_put, (gpointer)RADIO_BUTTON);
  gtk_tooltips_set_tip(tooltips, bt, "Create Radio Button", NULL);
  gtk_box_pack_start(GTK_BOX(hbox), bt, FALSE, FALSE, 5);
  gtk_widget_show(hbox);
  label = gtk_label_new("Buttons");
  gtk_notebook_append_page(GTK_NOTEBOOK(notebook), hbox, label);
}

/*
** Create the "Texts" Notebook of the Main Window
*/
void		create_notebook_for_texts(GtkWidget	*notebook,
					  GtkTooltips *tooltips,
					  GdkBitmap	*mask,
					  GtkStyle	*style)
{
  GtkWidget	*label;
  GtkWidget	*bt;
  GtkWidget	*hbox;
  
  hbox = gtk_hbox_new(FALSE,0);
  bt = create_pixmap_bt("./xpm/label2.xpm", mask, style,
			select_widget_to_put, (gpointer)LABEL);
  gtk_tooltips_set_tip(tooltips, bt, "Create Label", NULL);
  gtk_box_pack_start(GTK_BOX(hbox), bt, FALSE, FALSE, 5);
  bt = create_pixmap_bt("./xpm/entry2.xpm", mask, style,
			select_widget_to_put, (gpointer)ENTRY);
  gtk_tooltips_set_tip(tooltips, bt, "Create Entry", NULL);
  gtk_box_pack_start(GTK_BOX(hbox), bt, FALSE, FALSE, 5);
  bt = create_pixmap_bt("./xpm/combo_box2.xpm", mask, style,
			select_widget_to_put, (gpointer)COMBO);
  gtk_tooltips_set_tip(tooltips, bt, "Create Combo Box", NULL);
  gtk_box_pack_start(GTK_BOX(hbox), bt, FALSE, FALSE, 5);
  bt = create_pixmap_bt("./xpm/gtk_text2.xpm", mask, style,
			select_widget_to_put, (gpointer)TEXT);
  gtk_tooltips_set_tip(tooltips, bt, "Create GTKText", NULL);
  gtk_box_pack_start(GTK_BOX(hbox), bt, FALSE, FALSE, 5);
  gtk_widget_show(hbox);
  label = gtk_label_new("Text");
  gtk_notebook_append_page(GTK_NOTEBOOK(notebook), hbox, label);
}

/*
** Create the "Gfx" Notebook of the Main Window
*/
void		create_notebook_for_gfx(GtkWidget	*notebook,
					GtkTooltips *tooltips,
					GdkBitmap	*mask,
					GtkStyle	*style)
{
  GtkWidget	*label;
  GtkWidget	*bt;
  GtkWidget	*hbox;
  
  hbox = gtk_hbox_new(FALSE,0);
  bt = create_pixmap_bt("./xpm/drawing_area2.xpm", mask, style,
			select_widget_to_put, (gpointer)DRAWING_AREA);
  gtk_tooltips_set_tip(tooltips, bt, "Create Drawing Area", NULL);
  gtk_box_pack_start(GTK_BOX(hbox), bt, FALSE, FALSE, 5);
  bt = create_pixmap_bt("./xpm/pixmap2.xpm", mask, style,
			select_widget_to_put, (gpointer)PIXMAP);
  gtk_tooltips_set_tip(tooltips, bt, "Create Pixmap", NULL);
  gtk_box_pack_start(GTK_BOX(hbox), bt, FALSE, FALSE, 5);
  gtk_widget_show(hbox);
  label = gtk_label_new("Gfx");
  gtk_notebook_append_page(GTK_NOTEBOOK(notebook), hbox, label);
}

/*
** Create the "Containers" Notebook of the Main Window
*/
void		create_notebook_for_containers(GtkWidget	*notebook,
					       GtkTooltips	*tooltips,
					       GdkBitmap	*mask,
					       GtkStyle		*style)
{
  GtkWidget	*label;
  GtkWidget	*bt;
  GtkWidget	*hbox;
  
  hbox = gtk_hbox_new(FALSE,0);
  bt = create_pixmap_bt("./xpm/frame2.xpm", mask, style,
			select_widget_to_put, (gpointer)FRAME);
  gtk_tooltips_set_tip(tooltips, bt, "Create Frame", NULL);
  gtk_box_pack_start(GTK_BOX(hbox), bt, FALSE, FALSE, 5);
  bt = create_pixmap_bt("./xpm/notebook2.xpm", mask, style,
			select_widget_to_put, (gpointer)NOTEBOOK);
  gtk_tooltips_set_tip(tooltips, bt, "Create NoteBook", NULL);
  gtk_box_pack_start(GTK_BOX(hbox), bt, FALSE, FALSE, 5);
  bt = create_pixmap_bt("./xpm/table2.xpm", mask, style,
			select_widget_to_put, (gpointer)TABLE);
  gtk_tooltips_set_tip(tooltips, bt, "Create Table of widgets", NULL);
  gtk_box_pack_start(GTK_BOX(hbox), bt, FALSE, FALSE, 5);
  gtk_widget_show(hbox);
  label = gtk_label_new("Containers");
  gtk_notebook_append_page(GTK_NOTEBOOK(notebook), hbox, label);
}

/*
** Create the "Others" Notebook of the Main Window
*/
void		create_notebook_for_others(GtkWidget	*notebook,
					   GtkTooltips	*tooltips,
					   GdkBitmap	*mask,
					   GtkStyle	*style)
{
  GtkWidget	*label;
  GtkWidget	*bt;
  GtkWidget	*hbox;

  hbox = gtk_hbox_new(FALSE,0);
  bt = create_pixmap_bt("./xpm/menu2.xpm", mask, style,
			select_widget_to_put, (gpointer)MENU);
  gtk_tooltips_set_tip(tooltips, bt, "Create Menu", NULL); 
  gtk_box_pack_start(GTK_BOX(hbox), bt, FALSE, FALSE, 5);
  bt = create_pixmap_bt("./xpm/option_menu2.xpm", mask, style,
			select_widget_to_put, (gpointer)OPTION_MENU);
  gtk_tooltips_set_tip(tooltips, bt, "Create Option Menu", NULL);
  gtk_box_pack_start(GTK_BOX(hbox), bt, FALSE, FALSE, 5);
  bt = create_pixmap_bt("./xpm/progress_bar2.xpm", mask, style,
			select_widget_to_put, (gpointer)PROGRESS_BAR);
  gtk_tooltips_set_tip(tooltips, bt, "Create Progress Bar", NULL);
  gtk_box_pack_start(GTK_BOX(hbox), bt, FALSE, FALSE, 5);
  bt = create_pixmap_bt("./xpm/clist2.xpm", mask, style,
			select_widget_to_put, (gpointer)CLIST);
  gtk_tooltips_set_tip(tooltips, bt, "Create CList", NULL);
  gtk_box_pack_start(GTK_BOX(hbox), bt, FALSE, FALSE, 5);
  gtk_widget_show(hbox);
  label = gtk_label_new("Others");
  gtk_notebook_append_page(GTK_NOTEBOOK(notebook), hbox, label);
}

/*
** Create the "Alignment" Notebook of the Main Window
*/
void		create_notebook_for_alignment(GtkWidget		*notebook,
					      GtkTooltips	*tooltips,
					      GdkBitmap		*mask,
					      GtkStyle		*style)
{
  GtkWidget	*label;
  GtkWidget	*bt;
  GtkWidget	*hbox;
  
  hbox = gtk_hbox_new(FALSE,0);
  bt = create_pixmap_bt("./xpm/left_align2.xpm", mask, style,
			select_widget_to_put, (gpointer)LEFT_ALIGN);
  gtk_tooltips_set_tip(tooltips, bt, "Left Alignment", NULL); 
  gtk_box_pack_start(GTK_BOX(hbox), bt, FALSE, FALSE, 5);
  bt = create_pixmap_bt("./xpm/right_align2.xpm", mask, style,
			select_widget_to_put, (gpointer)RIGHT_ALIGN);
  gtk_tooltips_set_tip(tooltips, bt, "Right Alignment", NULL);
  gtk_box_pack_start(GTK_BOX(hbox), bt, FALSE, FALSE, 5);
  bt = create_pixmap_bt("./xpm/top_align2.xpm", mask, style,
			select_widget_to_put, (gpointer)TOP_ALIGN);
  gtk_tooltips_set_tip(tooltips, bt, "Top Alignment", NULL);
  gtk_box_pack_start(GTK_BOX(hbox), bt, FALSE, FALSE, 5);
  bt = create_pixmap_bt("./xpm/bottom_align2.xpm", mask, style,
			select_widget_to_put, (gpointer)BOTTOM_ALIGN);
  gtk_tooltips_set_tip(tooltips, bt, "Bottom Alignment", NULL);
  gtk_box_pack_start(GTK_BOX(hbox), bt, FALSE, FALSE, 5);
  bt = create_pixmap_bt("./xpm/width_align2.xpm", mask, style,
			select_widget_to_put, (gpointer)WIDTH_ALIGN);
  gtk_tooltips_set_tip(tooltips, bt, "Width Alignment", NULL);
  gtk_box_pack_start(GTK_BOX(hbox), bt, FALSE, FALSE, 5);
  bt = create_pixmap_bt("./xpm/height_align2.xpm", mask, style,
			select_widget_to_put, (gpointer)HEIGHT_ALIGN);
  gtk_tooltips_set_tip(tooltips, bt, "Height Alignment", NULL);
  gtk_box_pack_start(GTK_BOX(hbox), bt, FALSE, FALSE, 5);
  gtk_widget_show(hbox);
  label = gtk_label_new("Alignment");
  gtk_notebook_append_page(GTK_NOTEBOOK(notebook), hbox, label);
}

/*
***************************************************
** Create the Widget Notebook of the Main Window **
***************************************************
*/
void		create_main_window_notebook(GtkWidget *vbox)
{
  GtkWidget	*table;
  GtkWidget	*notebook;
  GtkTooltips	*tooltips; 
  GdkBitmap	*mask;
  GtkStyle	*style;
  
  mask = NULL;
  table = gtk_table_new(1, 6, TRUE);
  gtk_widget_show(table);
  gtk_container_add(GTK_CONTAINER(vbox), table);
  notebook = gtk_notebook_new();
  gtk_table_attach(GTK_TABLE(table), notebook, 0, 5, 0, 1,
		   GTK_SHRINK, GTK_SHRINK, 0, 0);
  gtk_widget_show(notebook);
  tooltips = gtk_tooltips_new();
  style = gtk_widget_get_style(epingle->main_window);
  create_notebook_for_windows(notebook, tooltips, mask, style);
  create_notebook_for_buttons(notebook, tooltips, mask, style);
  create_notebook_for_texts(notebook, tooltips, mask, style);
  create_notebook_for_gfx(notebook, tooltips, mask, style);
  create_notebook_for_containers(notebook, tooltips, mask, style);
  create_notebook_for_others(notebook, tooltips, mask, style);
  create_notebook_for_alignment(notebook, tooltips, mask, style);
}

/*
****************************
** Create the Main Window **
****************************
*/
void		create_main_window(void)
{
  GtkWidget	*vbox;
  
  epingle->main_window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
  gtk_window_set_title(GTK_WINDOW(epingle->main_window), EPINGLE_VERSION);
  gtk_window_set_policy(GTK_WINDOW(epingle->main_window), FALSE, FALSE, TRUE); 
  gtk_signal_connect(GTK_OBJECT(epingle->main_window), "delete_event",
		     (GtkSignalFunc) gtk_exit, NULL);
  gtk_widget_set_uposition(epingle->main_window, 0, 0);
  vbox = gtk_vbox_new(FALSE, 0);
  gtk_container_add(GTK_CONTAINER(epingle->main_window), vbox);
  gtk_widget_show(vbox);
  gtk_widget_realize(epingle->main_window);
  create_main_window_menu(vbox);
  create_main_window_notebook(vbox);
  gl_sbar = gtk_statusbar_new();      
  gtk_box_pack_start(GTK_BOX(vbox), gl_sbar, TRUE, TRUE, 0);
  gtk_widget_show(gl_sbar);
  gl_sbar_context_id = gtk_statusbar_get_context_id(GTK_STATUSBAR(gl_sbar),
						    "Epingle Statusbar");
  gtk_widget_show(epingle->main_window);
}
