/*
** notebook.c
** 
** Made by (Maxime VERNIER)
** Login   <vernie_m@epita.fr>
** 
** Started on  Sun May 30 16:15:46 1999 Maxime VERNIER
** Last update Sat Apr  1 23:57:36 2000 Sebastien Thebert
*/
#include "main.h"
#include "restore.h"
#include "widget_events.h"

gchar	*gtk_notebook_get_text_tab_pos(GtkNotebook *notebook)
{
  switch(notebook->tab_pos)
    {
    case GTK_POS_LEFT:
      return "left";
      break;
    case GTK_POS_RIGHT:
      return "right";
      break;
    case GTK_POS_TOP:
      return "top";
      break;
    case GTK_POS_BOTTOM:
      return "bottom";
      break;
    }
  return ("error!");
}


void	cb_change_tab_pos(GtkWidget *entry, GtkWidget *widget)
{
  gchar	*text;
  
  text = gtk_entry_get_text(GTK_ENTRY(entry));
  if (!strcmp(text, "left"))
    gtk_notebook_set_tab_pos(GTK_NOTEBOOK(widget), GTK_POS_LEFT);
  else
    if (!strcmp(text, "right"))
      gtk_notebook_set_tab_pos(GTK_NOTEBOOK(widget), GTK_POS_RIGHT);
    else
      if (!strcmp(text, "top"))
	gtk_notebook_set_tab_pos(GTK_NOTEBOOK(widget), GTK_POS_TOP);
      else
	if (!strcmp(text, "bottom"))
	  gtk_notebook_set_tab_pos(GTK_NOTEBOOK(widget), GTK_POS_BOTTOM);
}

void		cb_show_tabs(GtkWidget *button, GtkWidget *widget)
{
  GtkWidget	*label;
  GtkWidget	*property;
  
  label = g_list_first(gtk_container_children(GTK_CONTAINER(button)))->data;
  if(GTK_TOGGLE_BUTTON(button)->active)
    {
      gtk_label_set(GTK_LABEL(label), "False");
      gtk_notebook_set_show_tabs(GTK_NOTEBOOK(widget), FALSE);
    }
  else
    {
      gtk_label_set(GTK_LABEL(label), "True");
      gtk_notebook_set_show_tabs(GTK_NOTEBOOK(widget), TRUE);
    }
  if ((property = gtk_object_get_data(GTK_OBJECT(epingle->win_properties),
				      "tab_pos")))
    gtk_widget_set_sensitive(property, !GTK_TOGGLE_BUTTON(button)->active);
  if((property = gtk_object_get_data(GTK_OBJECT(epingle->win_properties),
				     "scrollable")))
    gtk_widget_set_sensitive(property, !GTK_TOGGLE_BUTTON(button)->active);
}

void		cb_show_border(GtkWidget *button, GtkWidget *widget)
{
  GtkWidget	*label;
  
  label = g_list_first(gtk_container_children(GTK_CONTAINER(button)))->data;
  if(GTK_TOGGLE_BUTTON(button)->active)
    {
      gtk_label_set(GTK_LABEL(label), "False");
      gtk_notebook_set_show_border(GTK_NOTEBOOK(widget), FALSE);
    }
  else
    {
      gtk_label_set(GTK_LABEL(label), "True");
      gtk_notebook_set_show_border(GTK_NOTEBOOK(widget), TRUE);
    }
}

void	cb_add_page(GtkWidget *sender, GtkWidget *widget)
{
  gint	value, page_num;
  gint	i;
  
  value = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(sender)); 
  page_num = g_list_length(GTK_NOTEBOOK(widget)->children);
  if (value > page_num)
    {  
      GtkWidget *fixed, *label;
      gchar *buf;
      
      buf = xmalloc(TEXT_LENGTH * sizeof (*buf));
      for (i = page_num + 1; i == value; i++)
	{
	  fixed = gtk_fixed_new();
	  gtk_widget_show(fixed);
	  dragndrop_set_dest(fixed);
	  set_fixed_notebookpage_events(fixed);
	  /*  gtk_widget_set_usize(fixed, width, height);*/
	  sprintf(buf, "Page %d", value);
	  label = gtk_label_new(buf);
	  gtk_notebook_append_page(GTK_NOTEBOOK(widget), fixed, label);
	}
      free(buf);
    }
  else
    if (value < page_num)
      {
	for(i = page_num; value <= i; i--)
	  gtk_notebook_remove_page(GTK_NOTEBOOK(widget), i);
      }
}

void		cb_set_scrollable(GtkWidget *button, GtkWidget *widget )
{
  GtkWidget	*label;
  
  label = g_list_first(gtk_container_children(GTK_CONTAINER(button)))->data;
  if (GTK_TOGGLE_BUTTON(button)->active)
    {
      gtk_label_set(GTK_LABEL(label), "True");
      gtk_notebook_set_scrollable(GTK_NOTEBOOK(widget), TRUE);
    }
  else
    {
      gtk_label_set(GTK_LABEL(label), "False");
      gtk_notebook_set_scrollable(GTK_NOTEBOOK(widget), FALSE);
    }
}

void	cb_set_tab_label(GtkWidget * sender, GtkWidget * widget )
{
  gchar *text = gtk_entry_get_text(GTK_ENTRY(sender)); 
  gint	page_num = gtk_notebook_get_current_page(GTK_NOTEBOOK(widget));
  GtkWidget *child = gtk_notebook_get_nth_page(GTK_NOTEBOOK(widget), page_num);
  GtkWidget *label = gtk_notebook_get_tab_label(GTK_NOTEBOOK(widget), child);
  
  gtk_label_set(GTK_LABEL(label), text); 
}

void        cb_switch_page(GtkWidget * sender,
			   GtkNotebookPage *page,
			   gint page_num,
			   gpointer user_data)
{
  GtkWidget *entry = gtk_object_get_data(GTK_OBJECT(epingle->win_properties),
					 "label"); 
  GtkWidget *child = gtk_notebook_get_nth_page(GTK_NOTEBOOK(sender), page_num);
  GtkWidget *label = gtk_notebook_get_tab_label(GTK_NOTEBOOK(sender), child);
  gchar	*text;
  guint  *signal;
  
  gtk_label_get(GTK_LABEL(label), &text); 
  signal = gtk_object_get_data(GTK_OBJECT(entry), "changed_signal");
  gtk_signal_disconnect(GTK_OBJECT(entry), *signal); 
  gtk_entry_set_text(GTK_ENTRY(entry), text); 
  *signal = gtk_signal_connect(GTK_OBJECT(entry), "changed", 
			       GTK_SIGNAL_FUNC(cb_set_tab_label), sender); 
}

void		GtkNotebook_properties(gint row, GtkWidget *widget)
{
  GtkWidget	*property;
  gchar		*text;
  GtkWidget	*table;
  GtkWidget	*child, *label;
  gint		page_num;
  guint		*signal;

  table = gtk_object_get_data(GTK_OBJECT(epingle->win_properties),
			      "properties"); 
  AddPropertyLabel(table, row, "Show tabs", "Are the tabs visible ?");
  if(GTK_NOTEBOOK(widget)->show_tabs)
    property = AddToggleProperty(table, row, FALSE, "True");
  else 
    property = AddToggleProperty(table, row, TRUE, "False");
  gtk_signal_connect(GTK_OBJECT(property), "toggled", 
		     GTK_SIGNAL_FUNC(cb_show_tabs), widget);
  AddPropertyLabel(table, ++row, "Tabs position", "Position of the tabs");
  property = AddComboProperty(table, row, gtk_position_types());
  text = gtk_notebook_get_text_tab_pos(GTK_NOTEBOOK(widget));
  gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(property)->entry), text);
  gtk_signal_connect(GTK_OBJECT(GTK_COMBO(property)->entry), "changed",
		     GTK_SIGNAL_FUNC(cb_change_tab_pos), widget);
  gtk_object_set_data(GTK_OBJECT(epingle->win_properties),
		      "tab_pos", property); 

  AddPropertyLabel(table, ++row, "Scrollable", 
		   "Useful with a large number of pages");
  if(GTK_NOTEBOOK(widget)->scrollable)
    property = AddToggleProperty(table, row, TRUE, "True");
  else
    property = AddToggleProperty(table, row, FALSE, "False");
  gtk_signal_connect(GTK_OBJECT(property), "toggled", 
		     GTK_SIGNAL_FUNC(cb_set_scrollable), widget); 
  gtk_object_set_data(GTK_OBJECT(epingle->win_properties), "scrollable", property); 

  AddPropertyLabel(table, ++row, "Show border", "Is the border visible ?");
  if(GTK_NOTEBOOK(widget)->show_border)
    property = AddToggleProperty(table, row, FALSE, "True");
  else 
    property = AddToggleProperty(table, row, TRUE, "False");
  gtk_signal_connect(GTK_OBJECT(property), "toggled", 
		     GTK_SIGNAL_FUNC(cb_show_border), widget);
  
  AddPropertyLabel(table, ++row, "Pages", "Number of pages");
  property = AddSpinProperty(table, row, 
			     g_list_length(GTK_NOTEBOOK(widget)->children),
			     0, 100, 1, 5, 0);
  gtk_signal_connect(GTK_OBJECT(property), "changed", 
		     GTK_SIGNAL_FUNC(cb_add_page), widget); 
  
  AddPropertyLabel(table, ++row, "Label", "Label of the current page");
  property = AddEntryProperty(table, row);
  gtk_object_set_data(GTK_OBJECT(epingle->win_properties), "label", property); 
  gtk_signal_connect(GTK_OBJECT(widget), "switch-page", 
		     GTK_SIGNAL_FUNC(cb_switch_page), widget); 
  page_num = gtk_notebook_get_current_page(GTK_NOTEBOOK(widget));
  child = gtk_notebook_get_nth_page(GTK_NOTEBOOK(widget), page_num);
  label = gtk_notebook_get_tab_label(GTK_NOTEBOOK(widget), child);
  gtk_label_get(GTK_LABEL(label), &text);
  gtk_entry_set_text(GTK_ENTRY(property), text); 
  signal = xmalloc(sizeof (*signal));
  *signal = gtk_signal_connect(GTK_OBJECT(property), "changed", 
			       GTK_SIGNAL_FUNC(cb_set_tab_label), widget); 
  gtk_object_set_data(GTK_OBJECT(property), "changed_signal", signal); 
}

void		GtkNotebook_events(GtkWidget *table, GtkWidget *widget)
{
  GtkWidget	*property;
  
  add_common_widget_events(table, widget);
  AddPropertyLabel(table, NB_WIDGET_EV + 1, "switch-page",
		   "When a page of the notebook is switched"); 
  property = AddEntryProperty(table, NB_WIDGET_EV + 1);
}

void	GtkNotebook_save(FILE *fp, int tab, GtkWidget *widget)
{
  gint	i;
  gint	nb_pages;
  
  write_num_property(fp, tab, "SHOW_TABS", GTK_NOTEBOOK(widget)->show_tabs);
  write_num_property(fp, tab, "TAB_POS", GTK_NOTEBOOK(widget)->tab_pos);
  write_num_property(fp, tab, "SCROLLABLE", GTK_NOTEBOOK(widget)->scrollable);
  write_num_property(fp, tab, "SHOW_BORDER",GTK_NOTEBOOK(widget)->show_border);
  nb_pages = g_list_length(GTK_NOTEBOOK(widget)->children);
  write_num_property(fp, tab, "NB_PAGES", nb_pages);
  if (nb_pages > 0)
    for(i = 0; i < nb_pages; i++)
      {
	GtkNotebookPage *page;
        gchar *label;
	
       	page = g_list_nth(GTK_NOTEBOOK(widget)->children, i)->data;
	gtk_label_get(GTK_LABEL(page->tab_label), &label);
	write_str_property(fp, tab, "PG_LABEL", label);
      }
}


