/*
** preferences_editor.c
** 
** Made by (sebastien thebert)
** Login   <theber_s@epita.fr>
** 
** Started on  Sat Mar 20 18:07:30 1999 sebastien thebert
** Last update Tue Apr  4 23:59:36 2000 Sebastien Thebert
*/
#include "main.h"
#include "fontselection.h"

GtkWidget	*preview_text;

GdkColor	old_color_background;
GdkColor	old_color_include;
GdkColor	old_color_define;
GdkColor	old_color_normal;
GdkColor	old_color_reserved_word;
GdkColor	old_color_type;
GdkColor	old_color_string;
GdkColor	old_color_gtktype;
GdkColor	old_color_warning_compil;
GdkColor	old_color_error_compil;

gint		elt_list;

/*
** set color
*/
GdkColor	set_color(FILE *file)
{
  unsigned int	red;
  unsigned int	green;
  unsigned int	blue;
  GdkColor	cl;
  char		*type;
  
  type = xmalloc(sizeof (char) * LENGTH);
  fscanf(file, "%s\t%u:%u:%u\n", type, &red, &green, &blue);
  cl.red = red;
  cl.green = green;
  cl.blue = blue;
  free(type);
  return (cl);
}

/*
** load default colors
*/
void		load_default_colors_editor()
{
  FILE		*file;
  char		*type;
  
  type = xmalloc(sizeof (char) * LENGTH);
  if ((file = fopen("./EPIngle_editor.cfg","r")) != NULL)
    {
      fscanf(file, "%s\n", type);
      color->background = set_color(file);
      color->include = set_color(file);
      color->define = set_color(file);
      color->normal = set_color(file);
      color->reserved_word = set_color(file);
      color->type = set_color(file);
      color->string = set_color(file);
      color->gtktype = set_color(file);
      color->warning_compil = set_color(file);
      color->error_compil = set_color(file);
      fclose(file);
     }
  else
    g_error("EPingle ERROR: Can't find default colors !\n");
  free(type);
}

/*
** save_color
*/
void	save_color(FILE *file, GdkColor cl, char *type)
{
  fprintf(file, "%s\t%u:%u:%u\n", type, cl.red, cl.green, cl.blue);
}

/*
** save default colors editor
*/
void	save_default_colors_editor(GtkWidget *sender, GtkWidget *win)
{
  FILE	*file;
  
  if ((file = fopen("./EPIngle_editor.cfg", "w")) != NULL)
    {
      fprintf(file, "<COLORS_EDITOR>\n");
      save_color(file, color->background, "BACKGROUND");
      save_color(file, color->include, "INCLUDE");
      save_color(file, color->define, "DEFINE");
      save_color(file, color->normal, "NORMAL");
      save_color(file, color->reserved_word, "RESERVED_WORD");
      save_color(file, color->type, "TYPE");
      save_color(file, color->string, "STRING");
      save_color(file, color->gtktype, "GTKTYPE");
      save_color(file, color->warning_compil, "WARNING_COMPIL");
      save_color(file, color->error_compil, "ERROR_COMPIL");
      fclose(file);
    }
  else
    g_error("EPingle ERROR: Can't save default colors !\n");  
  refresh_all_text();
  gtk_widget_destroy(win);
}

/***********************************************************/
void	bt_ok_pref(GtkWidget *sender, GtkWidget *win)
{
  refresh_all_text();
  gtk_widget_destroy(win);
}

/***********************************************************/
void	restore_old_values(GtkWidget *sender, GtkWidget *win)
{
  color->background = old_color_background;
  color->include = old_color_include;
  color->define = old_color_define;
  color->normal = old_color_normal;
  color->reserved_word = old_color_reserved_word;
  color->type = old_color_type;
  color->string = old_color_string;
  color->gtktype = old_color_gtktype;
  color->warning_compil = old_color_warning_compil;
  color->error_compil = old_color_error_compil;
  gtk_widget_destroy(win);
}

/***********************************************************/
void	refresh_preview_text()
{
  epingle->edit_text = preview_text;
  gtk_text_freeze(GTK_TEXT(epingle->edit_text));
  gtk_text_backward_delete(GTK_TEXT(epingle->edit_text) ,
			   gtk_text_get_length(GTK_TEXT(epingle->edit_text)));
  coloration("#include \"epingle.h\"\n\n");
  coloration("#define EPINGLE 42\n\n");
  coloration("void main(void)\n{\n");
  coloration("GtkWidget *window;\n\n");
  coloration("printf(\"foobar\");\n");
  coloration("return (0);\n}\n");
  gtk_text_thaw(GTK_TEXT(epingle->edit_text));
}

/***********************************************************/
void		color_change(GtkWidget *colorsel)
{
  gdouble	color_array[3];
  GdkColor	gdk_color;
  
  gtk_color_selection_get_color(GTK_COLOR_SELECTION(colorsel), color_array);
  gdk_color.red = (guint16)(color_array[0] * 65535.0);
  gdk_color.green = (guint16)(color_array[1] * 65535.0);
  gdk_color.blue = (guint16)(color_array[2] * 65535.0);
  gdk_color_alloc(epingle->colormap, &gdk_color);
  switch (elt_list)
    {
    case 0:
      color->background = gdk_color;
      break;
    case 1:
      color->include = gdk_color;
      break;
    case 2:
      color->define = gdk_color;
      break;
    case 3:
      color->normal = gdk_color;
      break;
    case 4:
      color->reserved_word = gdk_color;
      break;
    case 5:
      color->type = gdk_color;
      break;
    case 6:
      color->string = gdk_color;
      break;
    case 7:
      color->gtktype = gdk_color;
      break;  
    case 8:
      color->warning_compil = gdk_color;
      break;
    case 9:
      color->error_compil = gdk_color;
      break; 
    }
  refresh_preview_text();
}

/***********************************************************/
void		clist_selection(GtkWidget *clist, gint row, gint column,
				GdkEventButton *event, gpointer *colorsel)
{
  gdouble	color_array[3];
  GdkColor	gdk_color;
  
  elt_list = row;
  switch(elt_list)
    {
    case 0:
      gdk_color = color->background;
      break;
    case 1:
      gdk_color = color->include;
      break;
    case 2:
      gdk_color = color->define;
      break;
    case 3:
      gdk_color = color->normal;
      break;
    case 4:
      gdk_color = color->reserved_word;
      break;
    case 5:
      gdk_color = color->type;
      break;
    case 6:
      gdk_color = color->string;
      break;
    case 7:
      gdk_color = color->gtktype;
      break;  
    case 8:
      gdk_color = color->warning_compil;
      break;
    case 9:
      gdk_color = color->error_compil;
      break; 
    }
  color_array[0] = (gdouble)(gdk_color.red / 65535.0);
  color_array[1] = (gdouble)(gdk_color.green / 65535.0);
  color_array[2] = (gdouble)(gdk_color.blue / 65535.0);
  gtk_color_selection_set_color(GTK_COLOR_SELECTION(colorsel), color_array);
}

/*
** show fontselector
*/
void	show_font_selector(GtkWidget *box)
{
  /*  GtkWidget	*fontsel = NULL;*/
  /*  */
  /*  fontsel = simple_font_selection_new();*/
  /*  gtk_widget_show(fontsel);*/
  /*  gtk_box_pack_start(GTK_BOX(box), fontsel, TRUE, TRUE, 5);*/
}

/*
** set old colors
*/
void	set_old_colors()
{
  old_color_background = color->background;
  old_color_include = color->include;
  old_color_define = color->define;
  old_color_normal = color->normal;
  old_color_reserved_word = color->reserved_word;
  old_color_type = color->type;
  old_color_string = color->string;
  old_color_gtktype = color->gtktype;
  old_color_warning_compil = color->warning_compil;
  old_color_error_compil = color->error_compil; 
}

/*
** create clist and color_selector in preferences window
*/
void		create_clist_and_color_select_pref(GtkWidget *hbox)
{
  GtkWidget	*clist;
  GtkWidget	*color_select;
  gint		i;
  gchar		*list[10][1] = { {"Background"}, {"Include"}, {"Define"},
				 {"Normal"}, {"Reserved Words"}, {"Type"},
				 {"String"}, {"Gtk/Gdk Type"},
				 {"Compilation Warning"},
				 {"Compilation Error"} };
  
  clist = gtk_clist_new(1);
  gtk_clist_set_selection_mode(GTK_CLIST(clist), GTK_SELECTION_BROWSE);
  gtk_clist_set_column_justification(GTK_CLIST(clist), 1, GTK_JUSTIFY_LEFT);
  gtk_clist_set_column_width(GTK_CLIST(clist), 0, 100);
  for (i = 0; i < 10; i++)
    gtk_clist_append(GTK_CLIST(clist), list[i]);
  gtk_widget_show(clist);
  gtk_widget_set_usize(clist, 140, 160);
  gtk_box_pack_start(GTK_BOX(hbox), clist, TRUE, TRUE, 5);
  color_select = gtk_color_selection_new();
  gtk_widget_show(color_select);
  gtk_box_pack_start(GTK_BOX(hbox), color_select, TRUE, TRUE, 5);
  gtk_signal_connect(GTK_OBJECT(clist), "select_row",
		     GTK_SIGNAL_FUNC(clist_selection), (gpointer)color_select);
  gtk_signal_connect(GTK_OBJECT(color_select), "color_changed",
		     (GtkSignalFunc)color_change, NULL);
}

/*
** create notebook in preferences window
*/
void		create_notebook_pref(GtkWidget *vbox)
{
  GtkWidget	*notebook;
  GtkWidget	*table;
  GtkWidget	*hbox;
  GtkWidget	*label;
  
  table = gtk_table_new(1, 2, TRUE);
  gtk_widget_show(table);
  gtk_box_pack_start(GTK_BOX(vbox), table, TRUE, TRUE, 2);
  notebook = gtk_notebook_new();
  gtk_table_attach(GTK_TABLE(table), notebook, 0, 2, 0, 1,
		   GTK_EXPAND | GTK_FILL | GTK_SHRINK,
		   GTK_EXPAND | GTK_FILL | GTK_SHRINK, 0, 0);
  gtk_widget_show(notebook);
  hbox = gtk_hbox_new(FALSE, 0);
  create_clist_and_color_select_pref(hbox);
  gtk_widget_show(hbox);
  label = gtk_label_new("Colors");
  gtk_notebook_append_page(GTK_NOTEBOOK(notebook), hbox, label);
  hbox = gtk_hbox_new(FALSE,0);
  show_font_selector(hbox);
  label = gtk_label_new("Fonts");
  gtk_widget_show(hbox);
  gtk_notebook_append_page(GTK_NOTEBOOK(notebook), hbox, label);
}

/*
** create preview_text in Preferences Window
*/
void	create_preview_text(GtkWidget *vbox)
{
  GtkWidget	*vscrollbar;
  GtkWidget	*hbox;
  
  hbox = gtk_hbox_new(FALSE, 0);
  preview_text = gtk_text_new(NULL, NULL);
  gtk_text_set_editable(GTK_TEXT(preview_text), FALSE);
  gtk_widget_show(preview_text);
  gtk_box_pack_start(GTK_BOX(hbox), preview_text, TRUE, TRUE, 5);
  vscrollbar = gtk_vscrollbar_new(GTK_TEXT(preview_text)->vadj);
  gtk_box_pack_start(GTK_BOX(hbox), vscrollbar, FALSE, FALSE, 0);
  gtk_widget_show(vscrollbar);
  gtk_widget_show(hbox);
  gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
}

/*
** create buttons in Preferences Window
*/
void		create_buttons_pref(GtkWidget *win, GtkWidget *vbox)
{
  GtkWidget	*bt;
  GtkWidget	*hbox;
  
  hbox = gtk_hbox_new(FALSE,0);
  bt = gtk_button_new_with_label("Ok");
  gtk_box_pack_start(GTK_BOX(hbox), bt, TRUE, TRUE, 5);
  gtk_signal_connect(GTK_OBJECT(bt),"clicked",
		     GTK_SIGNAL_FUNC(bt_ok_pref), win);
  gtk_widget_show(bt);
  bt = gtk_button_new_with_label("Cancel");
  gtk_box_pack_start(GTK_BOX(hbox), bt, TRUE, TRUE, 5);
  gtk_signal_connect(GTK_OBJECT(bt),"clicked",
		     GTK_SIGNAL_FUNC(restore_old_values),win);
  gtk_widget_show(bt);
  bt = gtk_button_new_with_label("Save Default");
  gtk_box_pack_start(GTK_BOX(hbox), bt, TRUE, TRUE, 5);
  gtk_signal_connect(GTK_OBJECT(bt),"clicked",
		     GTK_SIGNAL_FUNC(save_default_colors_editor), win);
  gtk_widget_show(bt);
  gtk_widget_show(hbox);
  gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 5);
}

/*
** Edit Preferences Window
*/
void		edit_preferences(GtkWidget *sender)
{
  GtkWidget	*win;
  GtkWidget	*vbox;
  
  win = gtk_window_new(GTK_WINDOW_TOPLEVEL);
  gtk_window_set_title(GTK_WINDOW(win),"Editor Preferences");
  set_old_colors();
  vbox = gtk_vbox_new(FALSE,0);
  create_notebook_pref(vbox);
  create_preview_text(vbox);
  create_buttons_pref(win, vbox);
  gtk_widget_show(vbox);
  gtk_container_add(GTK_CONTAINER(win), vbox);
  gtk_widget_show(win);
  refresh_preview_text();
}






