/*
** progress_bar.c
** 
** Made by (Maxime VERNIER)
** Login   <vernie_m@epita.fr>
** 
*/
#include "main.h"
#include "dragndrop.h"
#include "widget_events.h"

GList	*GtkProgressBarStyles()
{
  GList *list = NULL;
  
  list = g_list_append(list, "continuous");
  list = g_list_append(list, "discrete");
  return list;
}

gchar	*gtk_progress_bar_get_text_style(GtkProgressBar *progress_bar)
{
  switch(progress_bar->bar_style)
    {
    case GTK_PROGRESS_CONTINUOUS:
      return "continuous";
      break;
    case GTK_PROGRESS_DISCRETE:
      return "discrete";
      break;
    }
  return ("error!");
}

void	cb_change_style(GtkWidget *entry, GtkWidget *widget)
{
  gchar	*text;
  
  text = gtk_entry_get_text(GTK_ENTRY(entry));
  if (!strcmp(text, "continuous"))
    gtk_progress_bar_set_bar_style(GTK_PROGRESS_BAR(widget), 
				   GTK_PROGRESS_CONTINUOUS);
  else
    if (!strcmp(text, "discrete"))
      gtk_progress_bar_set_bar_style(GTK_PROGRESS_BAR(widget), 
				     GTK_PROGRESS_DISCRETE);
}

GList	*GtkProgressBarOrientations()
{
  GList *list = NULL;
  
  list = g_list_append(list, "left to right");
  list = g_list_append(list, "right to left");
  list = g_list_append(list, "bottom to top");
  list = g_list_append(list, "top to bottom");
  return list;
}

gchar	*gtk_progress_bar_get_text_orientation(GtkProgressBar *progress_bar)
{
  switch(progress_bar->orientation)
    {
    case GTK_PROGRESS_LEFT_TO_RIGHT:
      return "left to right";
      break;
    case GTK_PROGRESS_RIGHT_TO_LEFT:
      return "right to left";
      break;
    case GTK_PROGRESS_BOTTOM_TO_TOP:
      return "bottom to top";
      break;
    case GTK_PROGRESS_TOP_TO_BOTTOM:
      return "top to bottom";
      break;
    }
  return ("error!");
}

void	cb_change_orientation(GtkWidget *entry, GtkWidget *widget)
{
  gchar	*text;
  
  text = gtk_entry_get_text(GTK_ENTRY(entry));
  if (!strcmp(text, "left to right"))
    gtk_progress_bar_set_orientation(GTK_PROGRESS_BAR(widget), 
				     GTK_PROGRESS_LEFT_TO_RIGHT);
  else
    if (!strcmp(text, "right to left"))
      gtk_progress_bar_set_orientation(GTK_PROGRESS_BAR(widget), 
				       GTK_PROGRESS_RIGHT_TO_LEFT);
    else
      if (!strcmp(text, "bottom to top"))
	gtk_progress_bar_set_orientation(GTK_PROGRESS_BAR(widget), 
					 GTK_PROGRESS_BOTTOM_TO_TOP);
      else
	if (!strcmp(text, "top to bottom"))
	  gtk_progress_bar_set_orientation(GTK_PROGRESS_BAR(widget), 
					   GTK_PROGRESS_TOP_TO_BOTTOM);
}

void		cb_update_pb(GtkWidget *sender, GtkWidget *widget)
{
  gfloat	percentage;
  
  percentage = gtk_spin_button_get_value_as_float(GTK_SPIN_BUTTON(sender))/100;
  gtk_progress_bar_update(GTK_PROGRESS_BAR(widget), percentage);
}

void	cb_show_text(GtkWidget * sender, GtkWidget * widget )
{
  if (GTK_IS_TOGGLE_BUTTON(sender))
    {
      GtkWidget *label;
      GList     *children;
      
      children = gtk_container_children(GTK_CONTAINER(sender));
      label = g_list_first(children)->data; 
      if (GTK_TOGGLE_BUTTON(sender)->active)
	{
	  gtk_label_set_text(GTK_LABEL(label), "False");
	  gtk_progress_set_show_text(GTK_PROGRESS(widget), FALSE);
	}
      else 
	{
	  gtk_label_set_text(GTK_LABEL(label), "True");
	  gtk_progress_set_show_text(GTK_PROGRESS(widget), TRUE); 
	}
    }
}

void		GtkProgressBar_properties(gint row, GtkWidget *widget)
{
  GtkWidget	*prop_widget;
  gchar		*text;
  gfloat	percentage;
  GtkWidget	*table;

  g_return_if_fail(GTK_IS_PROGRESS_BAR(widget)); 
  table = gtk_object_get_data(GTK_OBJECT(epingle->win_properties),
			      "properties"); 
  AddPropertyLabel(table, row, "Percentage", "Percentage of the progress bar");
  percentage = gtk_progress_get_current_percentage(&GTK_PROGRESS_BAR
						   (widget)->progress);
  prop_widget = AddSpinProperty(table, row, percentage*100, 0, 100, 1, 10, 0);
  gtk_signal_connect(GTK_OBJECT(prop_widget), "changed", 
		     GTK_SIGNAL_FUNC(cb_update_pb), widget); 
  AddPropertyLabel(table, ++row, "Orientation",
		   "Orientation of the progress bar");
  prop_widget = AddComboProperty(table, row, GtkProgressBarOrientations());
  text = gtk_progress_bar_get_text_orientation(GTK_PROGRESS_BAR(widget));
  gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(prop_widget)->entry), text);
  gtk_signal_connect(GTK_OBJECT(GTK_COMBO(prop_widget)->entry), "changed",
		     GTK_SIGNAL_FUNC(cb_change_orientation), widget);
  AddPropertyLabel(table, ++row, "Style", "Style of the progress bar");
  prop_widget = AddComboProperty(table, row, GtkProgressBarStyles());
  text = gtk_progress_bar_get_text_style(GTK_PROGRESS_BAR(widget));
  gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(prop_widget)->entry), text);
  gtk_signal_connect(GTK_OBJECT(GTK_COMBO(prop_widget)->entry), "changed",
		     GTK_SIGNAL_FUNC(cb_change_style), widget);
  AddPropertyLabel(table, ++row, "Show text", "Visibility of the text");
  if (GTK_PROGRESS(widget)->show_text)
    prop_widget = AddToggleProperty(table, row, FALSE, "True");
  else
    prop_widget = AddToggleProperty(table, row, TRUE, "False");
  gtk_signal_connect(GTK_OBJECT(prop_widget), "toggled", 
		     GTK_SIGNAL_FUNC(cb_show_text), widget); 
}


/*
 *  Save 
 */

void	GtkProgressBar_save(FILE *fp, int tab, GtkWidget *widget)
{
  gint	i;
  
  for(i = 1; i <= tab; i++)
    fprintf(fp, "\t");
  fprintf(fp, "<PERCENTAGE>\t%f\n",
	  gtk_progress_get_current_percentage(GTK_PROGRESS(widget)));
  for(i = 1; i <= tab; i++)
    fprintf(fp, "\t");
  fprintf(fp, "<STYLE>\t\t%d\n", GTK_PROGRESS_BAR(widget)->bar_style);
  for(i=1; i<=tab; i++)
    fprintf(fp, "\t");
  fprintf(fp, "<ORIENTATION>\t%d\n", GTK_PROGRESS_BAR(widget)->orientation);
  for(i = 1; i <= tab; i++)
    fprintf(fp, "\t");
  fprintf(fp, "<SHOW_TEXT>\t%d\n", GTK_PROGRESS(widget)->show_text);
}



  
