/*
** table.c
** 
** Made by (sebastien thebert)
** Login   <theber_s@epita.fr>
** 
** Started on  Sun May 30 19:09:31 1999 sebastien thebert
** Last update Sat Apr  1 19:22:06 2000 Sebastien Thebert
*/
#include "main.h"

typedef struct	t_prop
{
  GtkWidget	*fixed;
  int		x, y, width, height;
  int		rows, columns;
  int		rows_spacing, columns_spacing;
  short		widget_type; 
}		table_prop;

/***********************************************************/
void	change_rows(GtkWidget *entry, gpointer tp)
{
  ((table_prop *)tp)->rows =
    atoi(gtk_entry_get_text(GTK_ENTRY(entry)));
}

/***********************************************************/
void	change_columns(GtkWidget *entry, gpointer tp)
{
  ((table_prop *)tp)->columns =
    atoi(gtk_entry_get_text(GTK_ENTRY(entry)));
}

/***********************************************************/
void	change_rows_spacing(GtkWidget *entry, gpointer tp)
{
  ((table_prop *)tp)->rows_spacing =
    atoi(gtk_entry_get_text(GTK_ENTRY(entry)));
}

/***********************************************************/
void	change_columns_spacing(GtkWidget *entry, gpointer tp)
{
  ((table_prop *)tp)->columns_spacing =
    atoi(gtk_entry_get_text(GTK_ENTRY(entry)));
}

/***********************************************************/
void	change_widget_type(GtkWidget *entry, gpointer tp)
{
  char	*str_widget;
  
  
  str_widget = gtk_entry_get_text(GTK_ENTRY(entry));
  
  if (strcmp(str_widget, "Button") == 0)
    ((table_prop *)tp)->widget_type = BUTTON;
  if (strcmp(str_widget, "Toggle Button") == 0)
    ((table_prop *)tp)->widget_type = TOGGLE_BUTTON;
  if (strcmp(str_widget, "Check Button") == 0)
    ((table_prop *)tp)->widget_type = CHECK_BUTTON;
  if (strcmp(str_widget, "Radio Button") == 0)
    ((table_prop *)tp)->widget_type = RADIO_BUTTON;
  if (strcmp(str_widget, "Label") == 0)
    ((table_prop *)tp)->widget_type = LABEL;
  if (strcmp(str_widget, "Entry") == 0)
    ((table_prop *)tp)->widget_type = ENTRY;
  if (strcmp(str_widget, "ComboBox") == 0)
    ((table_prop *)tp)->widget_type = COMBO;
  if (strcmp(str_widget, "Drawing Area") == 0)
    ((table_prop *)tp)->widget_type = DRAWING_AREA;
}

/***********************************************************/
void			create_table(GtkWidget *sender, gpointer tp)
{
  GtkWidget		*table, *eventbox;
  GtkWidget		*widget = NULL;
  GtkRadioButton	*last_radio_bt = NULL;
  gint			i, i2;
  
  eventbox = gtk_event_box_new();
  gtk_widget_show(eventbox);
  table = gtk_table_new(((table_prop *)tp)->rows,
			((table_prop *)tp)->columns, TRUE);
  gtk_table_set_row_spacings(GTK_TABLE(table),
			     ((table_prop *)tp)->rows_spacing);
  gtk_table_set_col_spacings(GTK_TABLE(table),
			     ((table_prop *)tp)->columns_spacing);
  gtk_widget_show(table);
  name_generation(table, TABLE);
  hierarchy_add(table);
  for(i = 0; i < ((table_prop *)tp)->columns; i++)
    for(i2 = 0; i2 < ((table_prop *)tp)->rows; i2++)
      {
	switch(((table_prop *)tp)->widget_type)
	  {
	  case BUTTON :
	    widget = gtk_button_new_with_label("Button");
	    break;
	  case TOGGLE_BUTTON :
	    widget = gtk_toggle_button_new_with_label("Toggle");
	    break; 
	  case CHECK_BUTTON :
	    widget = gtk_check_button_new_with_label("Check");
	    break;
	  case RADIO_BUTTON :
	    if (last_radio_bt == NULL)
	      widget = gtk_radio_button_new(NULL);
	    else
	      widget = gtk_radio_button_new(gtk_radio_button_group
					    (last_radio_bt));
	    last_radio_bt = GTK_RADIO_BUTTON(widget);
	    break;
	  case LABEL :
	    widget = gtk_label_new("Label");
	    break;
	  case ENTRY :
	    widget = gtk_entry_new();
	    break; 
	  case COMBO :
	    widget = gtk_combo_new();
	    break;
	  case DRAWING_AREA :
	    widget = gtk_drawing_area_new();
	    break; 
	  }
	gtk_widget_show(widget);
	name_generation(widget, ((table_prop *)tp)->widget_type);
	hierarchy_add(widget);
	set_widget_table_events(widget);
	gtk_table_attach_defaults(GTK_TABLE(table), widget,
				  i, i + 1, i2, i2 + 1);
      }
  gtk_container_add(GTK_CONTAINER(eventbox), table);
  set_table_events(table);
  gtk_widget_set_usize(eventbox, ((table_prop *)tp)->width,
		       ((table_prop *)tp)->height);
  gtk_fixed_put(GTK_FIXED(((table_prop *)tp)->fixed), eventbox, 
		((table_prop *)tp)->x, ((table_prop *)tp)->y);
  set_widget_coordinates(eventbox, ((table_prop *)tp)->x,
			 ((table_prop *)tp)->y,
			 ((table_prop *)tp)->width,
			 ((table_prop *)tp)->height);
  create_table_code(gtk_widget_get_name(get_win_parent(table)), table);
  gtk_widget_destroy(sender->parent->parent);
}

/***********************************************************/
void	cancel(GtkWidget *sender)
{
  gtk_widget_destroy(sender->parent->parent);
}

/***********************************************************/
GList	*set_widget_list()
{
  GList *list = NULL;
  
  list = g_list_append(list, "Button");
  list = g_list_append(list, "Toggle Button");
  list = g_list_append(list, "Check Button");
  list = g_list_append(list, "Radio Button");
  list = g_list_append(list, "Label");
  list = g_list_append(list, "Entry");
  list = g_list_append(list, "ComboBox");
  list = g_list_append(list, "Drawing Area");
  return (list);
}

/***********************************************************/
void		window_table(GtkWidget *fixed, int x1, int y1, int x2, int y2)
{
  GtkWidget	*window;
  GtkWidget	*table;
  GtkWidget	*label, *entry, *bt, *combo;
  GList		*list;
  table_prop	*table_properties;
  GtkAdjustment *adj;
  
  table_properties = xmalloc(sizeof (table_prop));
  table_properties->fixed = fixed;
  table_properties->x = x1;
  table_properties->y = y1;
  table_properties->width = x2 - x1;
  table_properties->height = y2 - y1;
  table_properties->rows = 1;
  table_properties->columns = 1;
  table_properties->rows_spacing = 0;
  table_properties->columns_spacing = 0;
  table_properties->widget_type = BUTTON;
  
  window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
  gtk_window_set_title(GTK_WINDOW(window), "Widget Table");
  
  table = gtk_table_new(2, 7, FALSE);
  
  label = gtk_label_new("Number of rows");
  gtk_widget_show(label);
  gtk_table_attach_defaults(GTK_TABLE(table), label, 0, 1, 0, 1);
  
  adj = (GtkAdjustment *)gtk_adjustment_new(1.0, 0.0, 100.0,
					    1.0, 5.0, 0.0);
  entry = gtk_spin_button_new(GTK_ADJUSTMENT(adj), 1, 0);
  gtk_entry_set_text(GTK_ENTRY(entry), int_to_str(table_properties->rows));
  gtk_widget_show(entry);
  gtk_signal_connect(GTK_OBJECT(entry), "changed",
		     GTK_SIGNAL_FUNC(change_rows), (gpointer)table_properties);
  gtk_table_attach_defaults(GTK_TABLE(table), entry, 1, 2, 0, 1);
  
  label = gtk_label_new("Number of columns");
  gtk_widget_show(label);
  gtk_table_attach_defaults(GTK_TABLE(table), label, 0, 1, 1, 2);
  adj = (GtkAdjustment *)gtk_adjustment_new(1.0, 0.0, 100.0,
					    1.0, 5.0, 0.0);
  entry = gtk_spin_button_new(GTK_ADJUSTMENT(adj), 1, 0);
  gtk_entry_set_text(GTK_ENTRY(entry), int_to_str(table_properties->columns));
  gtk_widget_show(entry);
  gtk_signal_connect(GTK_OBJECT(entry), "changed",
		     GTK_SIGNAL_FUNC(change_columns),
		     (gpointer)table_properties);
  gtk_table_attach_defaults(GTK_TABLE(table), entry, 1, 2, 1, 2);
  
  label = gtk_label_new("Rows Spacing");
  gtk_widget_show(label);
  gtk_table_attach_defaults(GTK_TABLE(table), label, 0, 1, 2, 3);
  adj = (GtkAdjustment *)gtk_adjustment_new(1.0, 0.0, 100.0,
					    1.0, 5.0, 0.0);
  entry = gtk_spin_button_new(GTK_ADJUSTMENT(adj), 1, 0);
  gtk_entry_set_text(GTK_ENTRY(entry),
		     int_to_str(table_properties->rows_spacing));
  gtk_widget_show(entry);
  gtk_signal_connect(GTK_OBJECT(entry), "changed",
		     GTK_SIGNAL_FUNC(change_rows_spacing),
		     (gpointer)table_properties);
  gtk_table_attach_defaults(GTK_TABLE(table), entry, 1, 2, 2, 3);
  
  label = gtk_label_new("Columns Spacing");
  gtk_widget_show(label);
  gtk_table_attach_defaults(GTK_TABLE(table), label, 0, 1, 3, 4);
  adj = (GtkAdjustment *)gtk_adjustment_new(1.0, 0.0, 100.0,
					    1.0, 5.0, 0.0);
  entry = gtk_spin_button_new(GTK_ADJUSTMENT(adj), 1, 0);
  gtk_entry_set_text(GTK_ENTRY(entry),
		     int_to_str(table_properties->columns_spacing));
  gtk_widget_show(entry);
  gtk_signal_connect(GTK_OBJECT(entry), "changed",
		     GTK_SIGNAL_FUNC(change_columns_spacing),
		     (gpointer)table_properties);
  gtk_table_attach_defaults(GTK_TABLE(table), entry, 1, 2, 3, 4);
  
  label = gtk_label_new("Type of widget");
  gtk_widget_show(label);
  gtk_table_attach_defaults(GTK_TABLE(table), label, 0, 1, 4, 5);
  combo = gtk_combo_new();
  gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(combo)->entry), "Button");
  gtk_entry_set_editable(GTK_ENTRY(GTK_COMBO(combo)->entry), FALSE);
  list = set_widget_list();
  gtk_combo_set_popdown_strings(GTK_COMBO(combo), list);
  gtk_widget_show(combo);
  gtk_signal_connect(GTK_OBJECT(GTK_ENTRY(GTK_COMBO(combo)->entry)), "changed",
		     GTK_SIGNAL_FUNC(change_widget_type),
		     (gpointer)table_properties);
  gtk_table_attach_defaults(GTK_TABLE(table), combo, 1, 2, 4, 5);
  
  bt = gtk_button_new_with_label("Ok");
  gtk_widget_show(bt);
  gtk_signal_connect(GTK_OBJECT(bt), "clicked", GTK_SIGNAL_FUNC(create_table),
		     (gpointer)table_properties);  
  gtk_table_attach_defaults(GTK_TABLE(table), bt, 0, 1, 5, 6);
  bt = gtk_button_new_with_label("Cancel");
  gtk_widget_show(bt);
  gtk_signal_connect(GTK_OBJECT(bt), "clicked",
		     GTK_SIGNAL_FUNC(cancel), NULL);  
  gtk_table_attach_defaults(GTK_TABLE(table), bt, 1, 2, 5, 6);
  gtk_widget_show(table);
  gtk_container_add(GTK_CONTAINER(window), table);
  gtk_widget_show(window); 
}






