#include "main.h"

GList	*GtkToolbarStyleList()
{
  GList *list = NULL;
  
  list = g_list_append(list, "text");
  list = g_list_append(list, "icons");
  list = g_list_append(list, "both");
  return list;
}

GList	*GtkToolbarSpaceStyleList()
{
  GList *list = NULL;
  
  list = g_list_append(list, "empty");
  list = g_list_append(list, "line");
  return list;
}

void	cb_set_orientation(GtkWidget * sender, GtkWidget * widget )
{
  g_return_if_fail(GTK_IS_TOOLBAR(widget)); 
  if(GTK_IS_ENTRY(sender))
    {
      gchar *text;
      GtkOrientation orientation;

      text = gtk_entry_get_text(GTK_ENTRY(sender));
      orientation = get_orientation(text);
      gtk_toolbar_set_orientation(GTK_TOOLBAR(widget), orientation); 
    }
}

GtkToolbarStyle		get_toolbar_style(gchar *text)
{
  GtkToolbarStyle	style;
  
  if (!strcmp(text, "icons"))
    style = GTK_TOOLBAR_ICONS;
  else 
    if (!strcmp(text, "text"))
      style = GTK_TOOLBAR_TEXT;
    else
      style = GTK_TOOLBAR_BOTH;
  return style;
}

gchar	*get_text_toolbar_style(GtkToolbarStyle style)
{
  gchar *text = NULL;
  
  switch(style)
    {
    case GTK_TOOLBAR_ICONS:
      text = "icons";
      break;
    case GTK_TOOLBAR_TEXT:
      text = "text";
      break;
    case GTK_TOOLBAR_BOTH:
      text = "both";
      break;
    }
  return text;
}

GtkToolbarSpaceStyle	get_toolbar_space_style(gchar *text)
{
  GtkToolbarSpaceStyle	style;
  
  if (!strcmp(text, "empty"))
    style = GTK_TOOLBAR_SPACE_EMPTY;
  else 
    style = GTK_TOOLBAR_SPACE_LINE;
  return style;
}

void	cb_set_toolbar_style(GtkWidget *sender, GtkWidget *widget)
{
  g_return_if_fail(GTK_IS_TOOLBAR(widget)); 
  if(GTK_IS_ENTRY(sender))
    {
      gchar *text;
      GtkToolbarStyle style;
      
      text = gtk_entry_get_text(GTK_ENTRY(sender));
      style = get_toolbar_style(text);
      gtk_toolbar_set_style(GTK_TOOLBAR(widget), style);
    }
}

static void cb_set_space_style(GtkWidget *sender, GtkWidget *widget)
{
  g_return_if_fail(GTK_IS_TOOLBAR(widget)); 
  if(GTK_IS_ENTRY(sender))
    {
      gchar *text;
      GtkToolbarSpaceStyle space_style;
      
      text = gtk_entry_get_text(GTK_ENTRY(sender));
      space_style = get_toolbar_space_style(text);
      gtk_toolbar_set_space_style(GTK_TOOLBAR(widget), space_style);
    }
}

static gchar	*get_text_space_style(GtkToolbarSpaceStyle style)
{
  gchar		*text = NULL;
  
  switch(style)
    {
    case GTK_TOOLBAR_SPACE_EMPTY:
      text = "empty";
      break;
    case GTK_TOOLBAR_SPACE_LINE:
      text = "line";
      break;
    }
  return text;
}

static void cb_set_space_size(GtkWidget *sender, GtkWidget *widget)
{
  g_return_if_fail(GTK_IS_TOOLBAR(widget)); 
  if(GTK_IS_SPIN_BUTTON(sender))
    {
      gint value;
      
      value = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(sender)); 
      gtk_toolbar_set_space_size(GTK_TOOLBAR(widget), value);
    }
}

static void cb_set_tooltip(GtkWidget *sender, GtkWidget *widget)
{
  g_return_if_fail(GTK_IS_TOOLBAR(widget)); 
  if(GTK_IS_TOGGLE_BUTTON(sender))
    {
      GtkWidget *label;
      
      label = g_list_first(gtk_container_children(GTK_CONTAINER(sender)))->data; 
      if(GTK_TOGGLE_BUTTON(sender)->active)
	gtk_label_set(GTK_LABEL(label), "False");
      else
	gtk_label_set(GTK_LABEL(label), "True");
      gtk_toolbar_set_tooltips(GTK_TOOLBAR(widget), 
			       !GTK_TOGGLE_BUTTON(sender)->active);
    }
}

static void cb_set_button_relief(GtkWidget *sender, GtkWidget *widget)
{
  g_return_if_fail(GTK_IS_TOOLBAR(widget)); 
  if(GTK_IS_ENTRY(sender))
    {
      gchar *text;
      GtkReliefStyle relief_style;
      
      text = gtk_entry_get_text(GTK_ENTRY(sender));
      relief_style = get_relief_style(text);
      gtk_toolbar_set_button_relief(GTK_TOOLBAR(widget), relief_style);
    }
}

void		GtkToolbar_properties(GtkWidget *widget)
{
  GtkWidget	*entry;
  GList		*list;
  gchar		*text;
  GtkWidget	*table;
  
  g_return_if_fail(GTK_IS_TOOLBAR(widget ));
  table = gtk_object_get_data(GTK_OBJECT(epingle->win_properties),
			      "properties"); 
  AddPropertyLabel(table, NB_WIDGET_PROP + 1, 
		   "Orientation", "Orientation of the toolbar");
  list = GtkOrientationList();
  entry = AddComboProperty(table, NB_WIDGET_PROP+1, list);
  text = get_text_orientation(GTK_TOOLBAR(widget)->orientation);
  gtk_entry_set_text(GTK_ENTRY(entry), text); 
  gtk_signal_connect(GTK_OBJECT(entry), "changed", 
		     GTK_SIGNAL_FUNC(cb_set_orientation), widget); 
  AddPropertyLabel(table, NB_WIDGET_PROP + 2, 
		   "Style", "Style of the toolbar");
  list = GtkToolbarStyleList();
  entry = AddComboProperty(table, NB_WIDGET_PROP+2, list);
  text = get_text_toolbar_style(GTK_TOOLBAR(widget)->style);
  gtk_entry_set_text(GTK_ENTRY(entry), text); 
  gtk_signal_connect(GTK_OBJECT(entry), "changed", 
		     GTK_SIGNAL_FUNC(cb_set_toolbar_style), widget); 
  AddPropertyLabel(table, NB_WIDGET_PROP + 3, 
		   "Space size", "Space size of the toolbar");
  entry = AddSpinProperty(table, NB_WIDGET_PROP + 3, 
			  GTK_TOOLBAR(widget)->space_size,
			  0, 1000, 1, 10, 0);
  gtk_signal_connect(GTK_OBJECT(entry), "changed", 
		     GTK_SIGNAL_FUNC(cb_set_space_size), widget); 
  AddPropertyLabel(table, NB_WIDGET_PROP + 4, 
		   "Space style", "Space style of the toolbar");
  list = GtkToolbarSpaceStyleList();
  entry = AddComboProperty(table, NB_WIDGET_PROP + 4, list);
  text = get_text_space_style(GTK_TOOLBAR(widget)->space_style);
  gtk_entry_set_text(GTK_ENTRY(entry), text); 
  gtk_signal_connect(GTK_OBJECT(entry), "changed", 
		     GTK_SIGNAL_FUNC(cb_set_space_style), widget); 
  AddPropertyLabel(table, NB_WIDGET_PROP + 5, 
		   "Tooltip enable", "Enable tooltip of the toolbar");
  entry = AddToggleProperty(table, NB_WIDGET_PROP + 5, FALSE, "True");
  gtk_signal_connect(GTK_OBJECT(entry), "toggled", 
		     GTK_SIGNAL_FUNC(cb_set_tooltip), widget); 
  AddPropertyLabel(table, NB_WIDGET_PROP + 6, 
		   "Button relief", "Button relief of the toolbar");
  list = GtkReliefStyleList();
  entry = AddComboProperty(table, NB_WIDGET_PROP + 6, list);
  text = get_text_relief_style(gtk_toolbar_get_button_relief
			       (GTK_TOOLBAR(widget )));
  gtk_entry_set_text(GTK_ENTRY(entry), text); 
  gtk_signal_connect(GTK_OBJECT(entry), "changed", 
		     GTK_SIGNAL_FUNC(cb_set_button_relief), widget); 
}
