/*
** widget.c for EPingle in 
** 
** Made by Maxime Vernier
** Login   <Maxime Vernier@epita.fr>
** 
** Started on  Sat Apr  1 18:57:12 2000 Maxime Vernier
** Last update Sat Apr  1 19:16:07 2000 Sebastien Thebert
*/
#include "main.h" 

extern gboolean	found_in_hierarchy;

void		cb_change_name(gpointer entry, GtkWidget *widget)
{
  gchar		*name;
  gchar		*title;
    
  if (GTK_IS_ENTRY(entry))
    name = gtk_entry_get_text(GTK_ENTRY(entry));
  else
    name = entry;
  hierarchy_find_by_name(name);
  if (!found_in_hierarchy)
    {
      if (strlen(name))
	{
	  gtk_widget_set_name(widget, name);
  	  refresh_widget_code(widget);
	  title = xmalloc(TEXT_LENGTH * sizeof(gchar));
  	  sprintf(title, "%s properties", name);
  	  gtk_window_set_title(GTK_WINDOW(epingle->win_properties), title);
  	  free(title);
  	}
    }
}

static void	change_x(GtkWidget *entry, gpointer data)
{
  gint		x;
  GtkWidget	*widget;
  GtkWidget	*parent = NULL;
  
  widget = get_current_widget(); 
  x = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(entry));
  parent = widget_get_parent(widget);
  if(parent)
    {
      if(GTK_WIDGET_NO_WINDOW(widget))
	widget = widget->parent;
      gtk_fixed_move(GTK_FIXED(parent), widget, x, widget->allocation.y);
    }
  
  widget->allocation.x = x;
  
  if (GTK_IS_WINDOW(widget))
    refresh_window_code(widget);
  else
    refresh_widget_code_from_properties(widget);
}

static void	change_y(GtkWidget *entry, gpointer data)
{
  gint		y;
  GtkWidget	*widget;
  GtkWidget	*parent = NULL;
  
  widget = get_current_widget();
  y = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(entry));
  parent = widget_get_parent(widget);
  if(parent)
    {
      if(GTK_WIDGET_NO_WINDOW(widget))
	widget = widget->parent;
      gtk_fixed_move(GTK_FIXED(parent), widget, widget->allocation.x, y);
    }
  
  widget->allocation.y = y;
  
  if (GTK_IS_WINDOW(widget))
    refresh_window_code(widget);
  else
    refresh_widget_code_from_properties(widget);
}

static void	change_height(GtkWidget *entry, gpointer data)
{
  gint		i;
  GtkWidget	*widget;
  
  widget = get_current_widget(); 
  i = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(entry));
  widget->allocation.height = i;
  gtk_widget_set_usize(widget,
		       widget->allocation.width,
		       widget->allocation.height);
  if (GTK_IS_WINDOW(widget))
    refresh_window_code(widget);
  else
    refresh_widget_code_from_properties(widget);
}

static void	change_width(GtkWidget *entry, gpointer data)
{
  gint		i;
  GtkWidget	*widget;
  
  widget = get_current_widget();
  i = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(entry));
  widget->allocation.width = i;
  gtk_widget_set_usize(widget,
		       widget->allocation.width,
		       widget->allocation.height); 
  if (GTK_IS_WINDOW(widget))
    refresh_window_code(widget);
  else
    refresh_widget_code_from_properties(widget);
}

static void	cb_set_sensitive(GtkWidget *sender, GtkWidget *widget)
{
  if(GTK_IS_TOGGLE_BUTTON(sender))
    {
      GtkWidget *label_widget;
      gchar *label;
      
      label_widget = g_list_first(gtk_container_children(GTK_CONTAINER
							 (sender)))->data; 
      gtk_label_get(GTK_LABEL(label_widget), &label);
      if(!strcmp(label, "True"))
	{
	  gtk_label_set(GTK_LABEL(label_widget), "False");
	  gtk_widget_set_sensitive(widget, FALSE);
	}
      else
	{
	  gtk_label_set(GTK_LABEL(label_widget), "True"); 
	  gtk_widget_set_sensitive(widget, TRUE); 
	}
      if (GTK_IS_WINDOW(widget))
	refresh_window_code(widget);
      else
	refresh_widget_code_from_properties(widget);
    }
}

static void	cb_set_visible(GtkWidget *sender, GtkWidget *widget)
{
  if(GTK_IS_TOGGLE_BUTTON(sender))
    {
      GtkWidget *label;
      
      if(GTK_WIDGET_VISIBLE(widget))
	gtk_widget_hide(widget);
      else 
	gtk_widget_show(widget);
      label = g_list_first(gtk_container_children(GTK_CONTAINER
						  (sender)))->data;
      if (!GTK_TOGGLE_BUTTON(sender)->active)
	gtk_label_set(GTK_LABEL(label), "True");
      else 
	gtk_label_set(GTK_LABEL(label), "False");
      if (GTK_IS_WINDOW(widget))
	refresh_window_code(widget);
      else
	refresh_widget_code_from_properties(widget);
    }
}

static void	change_tooltip(GtkWidget *entry, GtkWidget *widget)
{
  GtkTooltips	*tooltips;
  gchar		*text;

  tooltips = gtk_tooltips_new();
  text = gtk_entry_get_text(GTK_ENTRY(entry)); 
  if(strcmp(text,""))
    {
      if(GTK_WIDGET_NO_WINDOW(widget))
	gtk_tooltips_set_tip(tooltips, widget->parent, text, NULL);
      else
	gtk_tooltips_set_tip(tooltips, widget, text, NULL);
      gtk_tooltips_enable(tooltips);
    }
  else
    {
      GtkTooltipsData *tooltips_data;
      
      if((tooltips_data = gtk_tooltips_data_get(widget))
	 && GTK_IS_TOOLTIPS(tooltips = tooltips_data->tooltips))
	gtk_tooltips_disable(tooltips);
    }
}

static void		change_delay(GtkWidget *entry, GtkWidget *widget)
{
  guint			delay;
  GtkTooltipsData	*tooltips_data;

  if(GTK_IS_EVENT_BOX(widget->parent))
    tooltips_data = gtk_tooltips_data_get(widget->parent);
  else
    tooltips_data = gtk_tooltips_data_get(widget);
  if(tooltips_data && GTK_IS_TOOLTIPS(tooltips_data->tooltips))
    {
      delay = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(entry));
      gtk_tooltips_set_delay(tooltips_data->tooltips, delay);
    }
}

void			add_common_widget_properties()
{
  GtkWidget		*entry;
  GtkWidget		*widget;
  GtkTooltipsData	*tooltips_data;
  gchar			*text;
  gint			value;
  GtkWidget		*table;
  guint			delay;
  
  widget = get_current_widget();
  table = gtk_object_get_data(GTK_OBJECT(epingle->win_properties),
			      "properties"); 
  AddPropertyLabel(table, 1, "Name", "Name of the widget");
  entry = AddEntryProperty(table, 1);
  text = gtk_widget_get_name(widget);
  gtk_entry_set_text(GTK_ENTRY(entry), text); 
  gtk_signal_connect(GTK_OBJECT(entry), "changed", 
		     GTK_SIGNAL_FUNC(cb_change_name), widget); 
  AddPropertyLabel(table, 2, "X", "Position of the widget");
  if (GTK_IS_EVENT_BOX(widget->parent))
    value = widget->parent->allocation.x;
  else
    value = widget->allocation.x;
  entry = AddSpinProperty(table, 2, value, 0, 10000, 1, 10, 0);
  gtk_object_set_data(GTK_OBJECT(epingle->win_properties), "X", entry); 
  gtk_signal_connect(GTK_OBJECT(entry), "changed", 
		     GTK_SIGNAL_FUNC(change_x), widget);
  AddPropertyLabel(table, 3, "Y", "Position of the widget");
  if (GTK_IS_EVENT_BOX(widget->parent))
    value = widget->parent->allocation.y;
  else
    value = widget->allocation.y;
  entry = AddSpinProperty(table, 3, value, 0, 10000, 1, 10, 0);
  gtk_object_set_data(GTK_OBJECT(epingle->win_properties), "Y", entry); 
  gtk_signal_connect(GTK_OBJECT(entry), "changed", 
		     GTK_SIGNAL_FUNC(change_y), widget);
  AddPropertyLabel(table, 4, "Width", "Size of the widget");
  value = widget->allocation.width;
  entry = AddSpinProperty(table, 4, value, 0, 10000, 1, 10, 0);
  gtk_object_set_data(GTK_OBJECT(epingle->win_properties), "WIDTH", entry); 
  gtk_signal_connect(GTK_OBJECT(entry), "changed", 
		     GTK_SIGNAL_FUNC(change_width), widget);
  AddPropertyLabel(table, 5, "Height", "Size of the widget");
  value = widget->allocation.height;
  entry = AddSpinProperty(table, 5, value, 0, 10000, 1, 10, 0);
  gtk_object_set_data(GTK_OBJECT(epingle->win_properties), "HEIGHT", entry); 
  gtk_signal_connect(GTK_OBJECT(entry), "changed", 
		     GTK_SIGNAL_FUNC(change_height), widget);
  AddPropertyLabel(table, 6, "Sensitive", "Is the widget sensitive?");
  if (GTK_WIDGET_IS_SENSITIVE(widget))
    entry = AddToggleProperty(table, 6, FALSE, "True");
  else
    entry = AddToggleProperty(table, 6, TRUE, "False");
  gtk_signal_connect(GTK_OBJECT(entry), "toggled", 
		     GTK_SIGNAL_FUNC(cb_set_sensitive),
		     widget); 
  AddPropertyLabel(table, 7, "Visible", "Is the widget visible?");
  if(GTK_WIDGET_VISIBLE(widget))
    entry = AddToggleProperty(table, 7, FALSE, "True");
  else
    entry = AddToggleProperty(table, 7, TRUE, "False");
  gtk_signal_connect(GTK_OBJECT(entry), "toggled", 
		     GTK_SIGNAL_FUNC(cb_set_visible),
		     widget); 
  AddPropertyLabel(table, 8, "Tooltip", "Tooltip");
  entry = AddEntryProperty(table, 8);
  if (GTK_IS_EVENT_BOX(widget->parent))
    tooltips_data = gtk_tooltips_data_get(widget->parent);
  else
    tooltips_data = gtk_tooltips_data_get(widget);
  text = "";
  if (tooltips_data)
    text = tooltips_data->tip_text;
  gtk_entry_set_text(GTK_ENTRY(entry), text);
  gtk_signal_connect(GTK_OBJECT(entry), "changed", 
		     GTK_SIGNAL_FUNC(change_tooltip), widget); 
  AddPropertyLabel(table, 9, 
		   "Tooltip delay", "in milliseconds (default is 500)");
  delay = 500;
  if (tooltips_data && GTK_IS_TOOLTIPS(tooltips_data->tooltips))
    delay = tooltips_data->tooltips->delay;
  entry = AddSpinProperty(table, 9, (gint)delay, 0, 10000, 100, 500, 0);
  gtk_signal_connect(GTK_OBJECT(entry), "changed", 
		     GTK_SIGNAL_FUNC(change_delay), widget); 
}




