#include "main.h"
#include "properties.h"
#include "restore.h"
#include "put_widget.h"

GList	*window_types()
{
  GList *list = NULL;
  
  list = g_list_append(list, "toplevel");
  list = g_list_append(list, "dialog");
  list = g_list_append(list, "popup");
  return list;
}

GList	*window_positions()
{
  GList *list = NULL;
  
  list = g_list_append(list, "none");
  list = g_list_append(list, "center");
  list = g_list_append(list, "mouse");
  return list;
}

gchar		*get_window_type(GtkWidget *window)
{
  GtkWindowType	type;
  
  type = GTK_WINDOW(window)->type;
  switch(type)
    {
    case GTK_WINDOW_TOPLEVEL:
      return "toplevel";
    case GTK_WINDOW_DIALOG:
      return "dialog";
    case GTK_WINDOW_POPUP:
      return "popup";
    default:
      return "unable to get window type";
    }
}

gchar			*get_window_position(GtkWidget *window)
{
  GtkWindowPosition	position;
  
  position = GTK_WINDOW(window)->position;
  switch(position)
    {
    case GTK_WIN_POS_NONE:
      return "none";
    case GTK_WIN_POS_CENTER:
      return "center";
    case GTK_WIN_POS_MOUSE:
      return "mouse";
    default:
      return "unable to get window position";
    } 
}

void	cb_change_window_type(GtkWidget *entry, GtkWidget *window)
{
  gchar	*text;
  
  text = gtk_entry_get_text(GTK_ENTRY(entry));
  set_window_type(window, text);
  refresh_window_code(window);
}

void	cb_change_window_position(GtkWidget *entry, GtkWidget *window)
{
  gchar	*text;
  
  text = gtk_entry_get_text(GTK_ENTRY(entry));
  set_window_position(window, text);
  refresh_window_code(window);
}

void	cb_change_title(GtkWidget *sender, GtkWidget *widget)
{
  if (GTK_IS_ENTRY(sender))
    {
      gchar *title;
      
      title = gtk_entry_get_text(GTK_ENTRY(sender));
      gtk_window_set_title(GTK_WINDOW(widget), title);
      refresh_window_code(widget);
    }
}

void		AddWindowProperties(GtkWidget *widget)
{
  GtkWidget	*entry;
  gchar		*title;
  GtkWidget	*table;
  
  table = gtk_object_get_data(GTK_OBJECT(epingle->win_properties),
			      "properties"); 
  AddPropertyLabel(table, NB_WIDGET_PROP+1, "Title", "Title of the window");
  entry = AddEntryProperty(table, NB_WIDGET_PROP+1);
  title = GTK_WINDOW(widget)->title;
  gtk_entry_set_text(GTK_ENTRY(entry), title); 
  gtk_signal_connect(GTK_OBJECT(entry), "changed", 
		     GTK_SIGNAL_FUNC(cb_change_title), widget); 
}

void		GtkWindow_properties(GtkWidget *widget)
{
  GtkWidget	*property;
  GtkWidget	*table;
  
  table = gtk_object_get_data(GTK_OBJECT(epingle->win_properties),
			      "properties"); 
  AddWindowProperties(widget);
  AddPropertyLabel(table, NB_WIN_PROP+1, "Type", "Window type");
  property = AddComboProperty(table, NB_WIN_PROP+1, window_types());
  gtk_signal_connect(GTK_OBJECT(GTK_COMBO(property)->entry), "changed",
		     GTK_SIGNAL_FUNC(cb_change_window_type), widget); 
  AddPropertyLabel(table, NB_WIN_PROP+2, "Position", 
		   "Where the window will appear");
  property = AddComboProperty(table, NB_WIN_PROP+2, window_positions());
  gtk_signal_connect(GTK_OBJECT(GTK_COMBO(property)->entry), "changed",
		     GTK_SIGNAL_FUNC(cb_change_window_position), widget);
}

