/*
** write_properties.c
** 
** Made by (Maxime VERNIER)
** Login   <vernie_m@epita.fr>
** 
** Started on  Tue May  4 14:53:08 1999 Maxime VERNIER
** Last update Fri Jun 18 03:35:14 1999 maxime vernier
*/

#include "global.h"
#include "save_events.h"

int
write_num_property(FILE *fp, int tab, char *label, int value)
{
  int i;

  for(i=0; i < tab; i++)
    fprintf(fp, "\t");
  return fprintf(fp, "<%s>\t%d\n", label, value);
}

int
write_str_property(FILE *fp, int tab, char *label, char *str)
{
  int i;

  for(i=0; i < tab; i++)
    fprintf(fp, "\t");
  return fprintf(fp, "<%s>\t%s\n", label, str);
}

void
write_common_properties(FILE *fp, GtkWidget *widget, int nb_tab)
{
  gint			i;
  gint			d_property;
  gchar			*text;
  GtkTooltipsData	*tooltips_data;
  
  d_property = get_widget_type(widget);
  for(i=1; i<=nb_tab; i++)
    fprintf(fp, "\t");
  fprintf(fp, "<TYPE>\t\t%d\n", d_property);
  if(GTK_WIDGET_NO_WINDOW(widget))
    d_property = widget->parent->allocation.x;
  else
    d_property = widget->allocation.x;
  for(i=1; i<=nb_tab; i++)
    fprintf(fp, "\t");
  fprintf(fp, "<X>\t\t%d\n", d_property);
  if(GTK_WIDGET_NO_WINDOW(widget))
    d_property = widget->parent->allocation.y;
  else
    d_property = widget->allocation.y;
  for(i=1; i<=nb_tab; i++)
    fprintf(fp, "\t");
  fprintf(fp, "<Y>\t\t%d\n", d_property);
  d_property = widget->allocation.width;
  for(i=1; i<=nb_tab; i++)
    fprintf(fp, "\t");
  fprintf(fp, "<WIDTH>\t\t%d\n", d_property);
  d_property = widget->allocation.height;
  for(i=1; i<=nb_tab; i++)
    fprintf(fp, "\t");
  fprintf(fp, "<HEIGHT>\t%d\n", d_property);
  if(GTK_WIDGET_IS_SENSITIVE(widget))
    text = "TRUE";
  else
    text = "FALSE";
  for(i=1; i<=nb_tab; i++)
    fprintf(fp, "\t");
  fprintf(fp, "<SENSITIVE>\t%s\n", text);
  if(GTK_WIDGET_VISIBLE(widget))
    text = "TRUE";
  else
    text = "FALSE";
  for(i=1; i<=nb_tab; i++)
    fprintf(fp, "\t");
  fprintf(fp, "<VISIBLE>\t%s\n", text);
  for(i=1; i<=nb_tab; i++)
    fprintf(fp, "\t");
  if(GTK_IS_EVENT_BOX(widget->parent))
    tooltips_data = gtk_tooltips_data_get(widget->parent); 
  else
    tooltips_data = gtk_tooltips_data_get(widget); 
  if(!tooltips_data) 
    text = ""; 
  else 
    text = tooltips_data->tip_text; 
  fprintf(fp, "<TOOLTIP>\t%s\n", text); 
  for(i=1; i<=nb_tab; i++) 
    fprintf(fp, "\t"); 
  if(tooltips_data && GTK_IS_TOOLTIPS(tooltips_data->tooltips)) 
    d_property = tooltips_data->tooltips->delay; 
  else 
    d_property = 500; 
  fprintf(fp, "<DELAY>\t\t%d\n", d_property); 
}

void
write_specific_window_properties(FILE *fp,GtkWidget *window,gint nb_tab)
{
  GtkWindowType		type;
  GtkWindowPosition	position;
  gint			i;
  
  for(i=1; i<=nb_tab; i++)
    fprintf(fp, "\t");
  type = GTK_WINDOW(window)->type;
  switch(type)
    {
    case GTK_WINDOW_TOPLEVEL:
      fprintf(fp, "<WINTYPE>\t%s\n","toplevel"); 
      break;
    case GTK_WINDOW_DIALOG:
      fprintf(fp, "<WINTYPE>\t%s\n","dialog"); 
      break;
    case GTK_WINDOW_POPUP:
      fprintf(fp, "<WINTYPE>\t%s\n","popup"); 
      break;
    default:
      fprintf(fp, "<WINTYPE>\t%s\n","unable to get wintype"); 
    }
  for(i=1; i<=nb_tab; i++)
    fprintf(fp, "\t");
  position = GTK_WINDOW(window)->position;
  switch(position)
    {
    case GTK_WIN_POS_NONE:
      fprintf(fp, "<POSITION>\t%s\n","none");
      break;
    case GTK_WIN_POS_CENTER:
      fprintf(fp, "<POSITION>\t%s\n","center"); 
      break;
    case GTK_WIN_POS_MOUSE:
      fprintf(fp, "<POSITION>\t%s\n","mouse");
      break;
    default:
      fprintf(fp, "<POSITION>\t%s\n","unable to get winpos");
    }
}

void
write_window_properties(FILE *fp,GtkWidget *window,gint nb_tab)
{
  gint		i;
  gint		type;
  
  for(i=1; i<=nb_tab; i++)
    fprintf(fp, "\t");
  fprintf(fp, "<TITLE>\t\t%s\n", GTK_WINDOW(window)->title);
  type = get_widget_type(window);
  if(type == WINDOW)
    write_specific_window_properties(fp,window,nb_tab);
}

void
write_button_properties(FILE *fp, GtkWidget *widget, gint nb_tab)
{
  GList		*children;
  gchar		*label;
  gint		i;
  GtkWidget	*label_widget;
  
  g_return_if_fail(GTK_IS_BUTTON(widget));
  for(i=1; i<=nb_tab; i++)
    fprintf(fp, "\t");
  children = gtk_container_children(GTK_CONTAINER(widget));
  label_widget = GTK_WIDGET(g_list_first(children)->data);
  gtk_label_get(GTK_LABEL(label_widget), &label);
  fprintf(fp, "<LABEL>\t\t%s\n", label);
}

void
write_toggle_button_properties(FILE *fp, GtkWidget *widget, int nb_tab)
{
  g_return_if_fail(GTK_IS_TOGGLE_BUTTON(widget));
  write_button_properties(fp, widget, nb_tab);
  write_num_property(fp, nb_tab, "TBT_STATE", 
		     GTK_TOGGLE_BUTTON(widget)->active);
}

void
write_label_properties(FILE *fp, GtkWidget *widget, gint nb_tab)
{
  gint		i;
  
  for(i=1; i<=nb_tab; i++)
    fprintf(fp, "\t");
  fprintf(fp, "<LABEL>\t\t%s\n", GTK_LABEL(widget)->label); 
}

void
write_frame_properties(FILE *fp, GtkWidget *widget, gint nb_tab)
{
  gint		i;
  
  for(i=1; i<=nb_tab; i++)
    fprintf(fp, "\t");
  fprintf(fp, "<LABEL>\t\t%s\n", GTK_FRAME(widget)->label);
}

void
write_widget_properties(FILE *fp, GtkWidget *widget, int nb_tab)
{
  gchar		*widget_name;
  GList		*children_list;
  GtkWidget	*tree_item;
  GtkWidget     *subtree;
  GtkWidget	*child;
  gint		i;
  gint		type;
  
  widget_name = gtk_widget_get_name(widget);
  for(i=1; i<=nb_tab; i++)
    fprintf(fp, "\t");
  fprintf(fp, "<%s>\n", widget_name);
  write_common_properties(fp, widget, nb_tab+1);
  type = get_widget_type(widget);
  switch(type)
    {
    case CLIST:
      GtkCList_save(fp, nb_tab+1, widget);
      break;
    case OPTION_MENU:
      GtkOptionMenu_save(fp, nb_tab+1, widget);
      break;
    case LABEL:
      write_label_properties(fp, widget, nb_tab+1);
      break;
    case CHECK_BUTTON:
    case TOGGLE_BUTTON:
      write_toggle_button_properties(fp, widget, nb_tab+1);
      save_toggle_button_events(fp, nb_tab+1, widget);
      break;
    case BUTTON:
      write_button_properties(fp, widget, nb_tab+1);
      save_button_events(fp, nb_tab+1, widget);
      break;
    case ENTRY:
      GtkEntry_save(fp, widget, nb_tab+1);
      save_entry_events(fp, nb_tab+1, widget);
      break;
    case FRAME:
      write_frame_properties(fp, widget, nb_tab+1);
      break;
    case COMBO:
      GtkCombo_save(fp, nb_tab+1, widget);
      break;
    case DRAWING_AREA:
      GtkDrawingArea_save(fp, nb_tab+1, widget);
      break;
    case MENU:
      GtkMenuBar_save(fp, nb_tab+1, widget);
      break;
    case NOTEBOOK:
      GtkNotebook_save(fp, nb_tab+1, widget);
      break;
    case PROGRESS_BAR:
      GtkProgressBar_save(fp, nb_tab+1, widget);
      break;
    case TEXT:
      GtkText_save(fp, nb_tab+1, widget);
      break;
    }
  tree_item = gtk_object_get_user_data(GTK_OBJECT(widget));
  if (tree_item)
    {
      subtree = GTK_TREE_ITEM(tree_item)->subtree; 
      if (subtree)
	{
	  children_list = GTK_TREE(subtree)->children;
	  if (children_list)
	    {
	      for(i=0; i<g_list_length(children_list); i++)
		{
		  fprintf(fp, "\n");
		  tree_item = g_list_nth(children_list, i)->data;
		  child = gtk_object_get_user_data(GTK_OBJECT(tree_item));
		  write_widget_properties(fp, child, nb_tab+1); 
		}
	    }
	}
    }
  for(i=1; i<=nb_tab; i++)
    fprintf(fp, "\t");
  fprintf(fp, "</%s>\n", widget_name);
}

void
write_colorselector_properties(FILE *fp, GtkWidget *widget, int nb_tab)
{
  gint		i;
  gint		policy;

  for(i=1; i<=nb_tab; i++)
    fprintf(fp, "\t");
  policy = GTK_COLOR_SELECTION(GTK_COLOR_SELECTION_DIALOG(widget)->colorsel)->policy;
  switch(policy)
    {
    case GTK_UPDATE_CONTINUOUS:
      fprintf(fp, "<POLICY>\t%s\n","continuous");
      break;
    case GTK_UPDATE_DISCONTINUOUS:
      fprintf(fp, "<POLICY>\t%s\n","discontinuous");
      break;
    case GTK_UPDATE_DELAYED:
      fprintf(fp, "<POLICY>\t%s\n","delayed");
      break;
    }
}




